asymreg.fx: Function to compute the result of the asymptotic regression...

View source: R/asymregfx.r

asymreg.fxR Documentation

Function to compute the result of the asymptotic regression model, as an allometric functional form.

Description

Function of the asymptotic regression model, based upon its parameters and a variable, as follows

y_i= \alpha + \left(\beta-\alpha\right) \left\{\mathrm{e}^{ \left[-\left(\mathrm{e}^{-\gamma}\right) x_i \right] }\right\},

where: y_i and x_i are the response and predictor variable, respectively, for the i-th observation; and the rest are parameters (i.e., coefficients).

Usage

asymreg.fx(x, alpha, beta, upsilon = 0)

Arguments

x

is the predictor variable.

alpha

is the coefficient-parameter \alpha.

beta

is the coefficient-parameter \beta.

upsilon

is an optional constant term that force the prediction of y when x=0. Thus, the new model becomes y_i = \alpha + \left(\Upsilon-\alpha\right) \left\{\mathrm{e}^{ \left[-\left(\mathrm{e}^{-\beta}\right) x_i \right] }\right\} , thus the model will have only two parameters. By default \Upsilon is set to 0.

Value

Returns the response variable based upon the predictor variable and the coefficients.

Author(s)

Christian Salas-Eljatib.

References

  • Pinheiro JC, DM Bates. 2000. Mixed-effects Models in S and Splus. New York, USA. Springer-Verlag. 528 p.

  • Salas-Eljatib C. 2025. Funciones alométricas: reparametrizaciones y características matemáticas. Documento de trabajo No. 1, Serie: Cuadernos de biometría, Laboratorio de Biometría y Modelación Forestal, Universidad de Chile. Santiago, Chile. 51 p. https://biometriaforestal.uchile.cl

Examples

#---------------------
# 2-parameters variant
# Predictor variable values to be used
time<-seq(0,50,by=0.1)
# Using the function, upsilon must be provided
y<-asymreg.fx(x=time,alpha=20,beta=2.5,upsilon =5)
plot(time,y,type="l",ylim=c(0,20))
 

biometrics documentation built on March 20, 2026, 5:09 p.m.