| bankfit | R Documentation |
Function that fits a list of models on a given dataframe.
bankfit(modlist, data, file = NULL, file.full = FALSE, trace = FALSE, ...)
modlist |
List that contains the models to be fitted. To know the structure, see examples below. |
data |
|
file |
a (writable binary-mode) connection or the name of the file where the data will be saved (when tilde expansion is done). |
file.full |
wheter to include all output ( |
trace |
logical value indicating if a trace of the iteration
progress of |
... |
Other options used to control de behavior of
|
model.list <- list(
mod1 = list(expr = vtot ~ I(dap^2) + I(dap^2 * atot^2) +I(d6),
pred.f = function(x, ...) x,
type = "lm"),
mod2 = list(expr = I(log(vtot)) ~ I(log(dap)) + I(log(atot)),
pred.f = function(x, ...) exp(x),
type = "lm"))
## example dataframe
df <- treevolruca2
head(df)
## fitting models to dataframe
bankfit(modlist = model.list, data = df)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.