curtis.fx: Function to computes the result of the Curtis's allometric...

View source: R/curtis.r

curtis.fxR Documentation

Function to computes the result of the Curtis's allometric model.

Description

Function of the traditional Curtis' allometric model, based upon two parameters, and a single predictor variable as follows

y_i= \alpha \left(\frac{x_i}{1+x_i} \right)^{\beta},

where: y_i and x_i are the response and predictor variable, respectively for the i-th observation; and the rest are parameters (i.e., coefficients).

Usage

curtis.fx(x, alpha, beta, upsilon = 0)

Arguments

x

is the predictor variable.

alpha

is the coefficient-parameter \alpha.

beta

is the coefficient-parameter \beta.

upsilon

is an optional constant term that force the prediction of y when x=0. Thus, the new model becomes y_i = \Upsilon+ f(x_i,\mathbf{\theta}), where \mathbf{\theta} is the vector of coefficients of the above described function represented by f(\cdot). The default value for \Upsilon is 0.

Value

Returns the response variable based upon the predictor variable and the coefficients.

Author(s)

Christian Salas-Eljatib.

References

  • Curtis RO. 1967. Height-diameter and height-diameter-age equations for second-growth Douglas-fir. Forest Sci. 13(4):365-375.

  • Salas-Eljatib C. 2025. Funciones alométricas: reparametrizaciones y características matemáticas. Documento de trabajo No. 1, Serie: Cuadernos de biometría, Laboratorio de Biometría y Modelación Forestal, Universidad de Chile. Santiago, Chile. 51 p. https://biometriaforestal.uchile.cl

Examples

# Predictor variable values to be used
time<-seq(5,60,by=0.01)
# Using the function
y<-curtis.fx(x=time,alpha=20,beta=8)
plot(time,y,type="l")
 

biometrics documentation built on March 20, 2026, 5:09 p.m.