| curtisori.fx | R Documentation |
Function of the originally proposed allometric model by Curtis, based upon two parameters, and a single predictor variable as follows
y_i= \frac{x_i}{\alpha +\beta x_i},
where: y_i and x_i are the response
and predictor variable, respectively for the i-th observation;
and the rest are parameters (i.e., coefficients). Please read the
details on this model in Salas-Eljatib (2025).
curtisori.fx(x, alpha, beta, upsilon = 0)
x |
is the predictor variable. |
alpha |
is the coefficient-parameter |
beta |
is the coefficient-parameter |
upsilon |
is an optional constant term that force the prediction
of y when x=0. Thus, the new model becomes
|
Returns the response variable based upon the predictor variable and the coefficients.
Christian Salas-Eljatib.
Curtis RO. 1967. Height-diameter and height-diameter-age equations for second-growth Douglas-fir. Forest Sci. 13(4):365-375.
Salas-Eljatib C. 2025. Funciones alométricas: reparametrizaciones y características matemáticas. Documento de trabajo No. 1, Serie: Cuadernos de biometría, Laboratorio de Biometría y Modelación Forestal, Universidad de Chile. Santiago, Chile. 51 p. https://biometriaforestal.uchile.cl
# Parameters
# Predictor variable values to be used
time<-seq(5,60,by=0.01)
# Using the function
y<-curtisori.fx(x=time,alpha=20,beta=8)
plot(time,y,type="l")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.