| domvar | R Documentation |
Computes the so-called dominant stand-level variable,
corresponding to the average of a tree-level variable for
the nref.ha largest sorting-tree-level diameter trees in 1-ha.
domvar(data, varint, varsort, plot.area, ndom.ha = 100)
data |
the tree-list dataframe of a sample plot, having
at least column |
varint |
The column name of the data having the tree-level variable of interest (e.g., "toth"). Can be entered as the actual name, without the need of using quotation marks. |
varsort |
The column name of the data having the tree-level variable
to be used as reference (e.g., "dbh") for defining the sorting variable
of interest. If there is only data for the |
plot.area |
A numeric value of the plot area in m |
ndom.ha |
It is the number of trees/ha used as reference. By default |
The original function was written by Dr Oscar García for computing top height, and the corresponding reference is provided. Nevertheless, several changes were applied, to make the current function provide a broader application. Regardless, the function aims to calculate a "dominant" stand-level variable by taking into account the plot area. Thus, requires having a dataframe having both the variable of interest (e.g., height) and the sorting variable used for the computation (e.g., diameter) for all trees in a sample plot, as well as, the plot area.
The main output is the calculated dominant stand-variable for the given sample plot. The unit of the computed variable is the same as the one used as variable of interest.
Christian Salas-Eljatib.
García O, Batho A. 2005. Top height estimation in lodgepole pine sample plots. Western Journal of Applied forestry 20(1):64-68.
# Dataframe to be used
df<-biometrics::eucaplot2
#' ?eucaplot2
#' head(df)
datana::descstat(df[,c("dap","atot")])
#' # Using the domvar function
domvar(data=df,varint = "atot",varsort = "atot",plot.area = 500)
domvar(data=df,varint = "atot",varsort = "dap",plot.area = 500)
domvar(data=df,varint = "atot",varsort = "dap",plot.area = 500,ndom.ha = 50)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.