| eucaplot | R Documentation |
Tree-level variables collected for all trees (even the variable height)
within a sample plot in a forestry plantation of Eucalyptus globulus near
Gorbea, southern Chile. The plot size is 500 m^{2}.
The plantation is 15 yr-old and had been subject to three thinnings.
data(eucaplot)
The dataframe contains four variables as follows:
Diameter at breast height, in cm.
health status (1: good, 2: medium, 3: bad).
stem shape for timber purposes (1: good, 2: medium, 3: bad).
Crown class (1: superior, 2: intermedium, 3: lower).
Total height, in m.
The data were provided courtesy of Dr Christian Salas-Eljatib (Universidad de Chile, Santiago, Chile).
Forest biometrics lecture notes, Prof. Christian Salas-Eljatib, Universidad de Chile. Santiago, Chile
data(eucaplot)
table(eucaplot$health)
library(datana)
descstat(eucaplot[,c("dbh","toth")])
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.