eucaplotr: Tree-list (realistic-) data in a sample plot established in a...

eucaplotrR Documentation

Tree-list (realistic-) data in a sample plot established in a Eucalyptus globulus plantation in southern Chile.

Description

Tree-level variables collected in a sample plot (area=500 m^{2}) in a forestry plantation of Eucalyptus globulus near Gorbea, in southern Chile. The variable height, was only measured in a sub-sample of trees within the plot. The plantation is 15 yr-old and had been subject to three thinnings.

Usage

data(eucaplotr)

Format

The dataframe contains four variables as follows:

dbh

Diameter at breast height, in cm.

health

health status (1: good, 2: medium, 3: bad).

shape

stem shape for timber purposes (1: good, 2: medium, 3: bad).

crown.class

Crown class (1: superior, 2: intermedium, 3: lower).

toth

Total height (in m), only available for some trees. Otherwise missing values are denoted by NA.

The data were provided courtesy of Dr Christian Salas-Eljatib (Universidad de Chile, Santiago, Chile).

References

  • Forest biometrics lecture notes, Prof. Christian Salas-Eljatib, Universidad de Chile. Santiago, Chile

Examples

data(eucaplotr)    
table(eucaplotr$shape)
library(datana) 
descstat(eucaplotr[,c("dbh","toth")])

biometrics documentation built on March 20, 2026, 5:09 p.m.