| expogral.fx | R Documentation |
Function of the generalized-exponential allometric model, based upon four parameters (i.e., coefficients) and a variable, as defined by the mathematical expression
y_i=
\mathrm{e}^{\left(\alpha +\frac{\beta}{x_i^{\gamma}+\delta} \right)},
where: y_i and x_i are the response
and predictor variable, respectively, for the i-th observation;
and the rest are parameters (i.e., coefficients).
Further details on this function can be found in
Salas-Eljatib (2025).
expogral.fx(x, alpha, beta, gamma, delta, upsilon = 0)
x |
is the predictor variable. |
alpha |
is the coefficient-parameter |
beta |
is the coefficient-parameter |
gamma |
is the coefficient-parameter |
delta |
is the coefficient-parameter |
upsilon |
is an optional constant term that force the prediction
of y when x=0. Thus, the new model becomes
|
Returns the response variable based upon the predictor variable and the coefficients.
Christian Salas-Eljatib.
Salas-Eljatib C. 2025. Funciones alométricas: reparametrizaciones y características matemáticas. Documento de trabajo No. 1, Serie: Cuadernos de biometría, Laboratorio de Biometría y Modelación Forestal, Universidad de Chile. Santiago, Chile. 51 p. https://biometriaforestal.uchile.cl
# Predictor variable values to be used
time<-seq(5,60,by=0.01)
# Using the function
y<-expogral.fx(x=time,alpha=3,beta=8,gamma=1,delta=1)
plot(time,y,type="l",col="blue")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.