expogralfull.fx: Function that computes the result of the Stage allometric...

View source: R/expogralfull.r

expogralfull.fxR Documentation

Function that computes the result of the Stage allometric model.

Description

Function of the fully generalized-exponential allometric model, based upon five parameters (i.e., coefficients) and a variable, as defined by the mathematical expression

y_i= \alpha \mathrm{e}^{\left(\beta +\frac{\gamma}{x_i^{\delta}+\epsilon} \right)},

where: y_i and x_i are the response and predictor variable, respectively, for the i-th observation; and the rest are parameters (i.e., coefficients). Further details on this function can be found in Salas-Eljatib (2025).

Usage

expogralfull.fx(x, alpha, beta, gamma, delta, epsilon, upsilon = 0)

Arguments

x

is the predictor variable.

alpha

is the coefficient-parameter \alpha.

beta

is the coefficient-parameter \beta.

gamma

is the coefficient-parameter \gamma.

delta

is the coefficient-parameter \delta.

epsilon

is the coefficient-parameter \epsilon.

upsilon

is an optional constant term that force the prediction of y when x=0. Thus, the new model becomes y_i = \Upsilon+ f(x_i,\mathbf{\theta}), where \mathbf{\theta} is the vector of coefficients of the above described function represented by f(\cdot). The default value for \Upsilon is 0.

Value

Returns the response variable based upon the predictor variable and the coefficients.

Author(s)

Christian Salas-Eljatib.

References

  • Salas-Eljatib C. 2025. Funciones alométricas: reparametrizaciones y características matemáticas. Documento de trabajo No. 1, Serie: Cuadernos de biometría, Laboratorio de Biometría y Modelación Forestal, Universidad de Chile. Santiago, Chile. 51 p. https://biometriaforestal.uchile.cl

Examples

# Predictor variable values to be used
time<-seq(5,60,by=0.01)
# Using the function
y<-expogralfull.fx(x=time,alpha=20,beta=.1,gamma=10,delta=1,
epsilon=1)
plot(time,y,type="l",col="red")
 

biometrics documentation built on March 20, 2026, 5:09 p.m.