gompertzm.fx: Function that computes the result of the modified Gompertz's...

View source: R/gompertzm.r

gompertzm.fxR Documentation

Function that computes the result of the modified Gompertz's model.

Description

Function of the Gompertz modified model, based upon parameters (i.e., coefficients) and a variable, as follows

y_i= \alpha \mathrm{e}^{\left(-\beta \mathrm{e}^{-\gamma x_i} \right)},

where: y_i and x_i are the response and predictor variable, respectively for the i-th observation; and the rest are parameters (i.e., coefficients). The Gompertz equation is a widely used allometric mathematical function.

Usage

gompertzm.fx(x, alpha, beta, gamma, upsilon = 0)

Arguments

x

is the predictor variable.

alpha

is the coefficient-parameter \alpha.

beta

is the coefficient-parameter \beta.

gamma

is the coefficient-parameter \gamma.

upsilon

is an optional constant term that force the prediction of y when x=0. Thus, the new model becomes y_i = \Upsilon+ f(x_i,\mathbf{\theta}), where \mathbf{\theta} is the vector of coefficients of the above described function represented by f(\cdot). The default value for \Upsilon is 0.

Value

Returns the response variable based upon the predictor variable and the coefficients.

Author(s)

Christian Salas-Eljatib.

References

  • Gompertz B. 1825. On the nature of the function expressive of the law of human mortality, and on a new mode of determining the value of life contingencies. Philosophical Transactions of the Royal Society of London 115:513–583.

  • Salas-Eljatib C, Mehtatalo L, Gregoire TG, Soto DP, Vargas-Gaete R. 2021. Growth equations in forest research: mathematical basis and model similarities. Current Forestry Reports 7:230-244. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1007/s40725-021-00145-8")}

  • Salas-Eljatib C. 2025. Funciones alométricas: reparametrizaciones y características matemáticas. Documento de trabajo No. 1, Serie: Cuadernos de biometría, Laboratorio de Biometría y Modelación Forestal, Universidad de Chile. Santiago, Chile. 51 p. https://biometriaforestal.uchile.cl

Examples

# Predictor variable values to be used
time<-seq(5,60,by=0.01)
# Using the function
y<-gompertzm.fx(x=time,alpha=25,beta=3.6,gamma=0.17)
plot(time,y,type="l")
 

biometrics documentation built on March 20, 2026, 5:09 p.m.