interpy2: A simple linear interpolation function applicable to two...

View source: R/interpy2.r

interpy2R Documentation

A simple linear interpolation function applicable to two vectors (X and Y), when the second element of Y is missing.

Description

A simple linear interpolation function applicable to two vectors (e.g., X and Y) of length three, suitable when the second element of Y is missing.

Usage

interpy2(xs = xs, ys = ys)

Arguments

xs

A numeric vector of length 3.

ys

A numeric vector of length 3, with the second position empty.

Value

The interpolated value for the second element of vector Y.

Author(s)

Christian Salas-Eljatib.

Examples

x<-c(0.2,0.8,1.3)
y<-c(48,NA,41)
interpy2(xs=x,ys=y)

biometrics documentation built on March 20, 2026, 5:09 p.m.