inv.fx: Function to compute the result of the simple linear inverse...

View source: R/invfx.r

inv.fxR Documentation

Function to compute the result of the simple linear inverse model.

Description

Function of the inverse model, based upon its two parameters and a variable, as follows

y_i = \alpha - \left(\frac{\beta}{x_i}\right),

where: y_i and x_i are the response and predictor variable, respectively for the i-th observation; and the rest are parameters (i.e., coefficients).

Usage

inv.fx(x, alpha, beta, upsilon = 0)

Arguments

x

is the predictor variable.

alpha

is the coefficient-parameter \alpha.

beta

is the coefficient-parameter \beta.

upsilon

is an optional constant term that force the prediction of y when x=0. Thus, the new model becomes y_i = \Upsilon + f(x_i,\mathbf{\theta}), where \mathbf{\theta} is the vector of coefficients of the above described function represented by f(\cdot). The default value for \Upsilon is 0. Note that this restriction must be imposed during the fitting of the model.

Value

Returns the response variable based upon the predictor variable and the coefficients.

Author(s)

Christian Salas-Eljatib.

References

  • Salas-Eljatib C. 2025. Funciones alométricas: reparametrizaciones y características matemáticas. Documento de trabajo No. 1, Serie: Cuadernos de biometría, Laboratorio de Biometría y Modelación Forestal, Universidad de Chile. Santiago, Chile. 51 p. https://biometriaforestal.uchile.cl

Examples

# Predictor variable to be used is 40 
# Using the function
inv.fx(x=40,alpha=25,beta=115)
# The effect of the constant term phi
inv.fx(x=40,alpha=25,beta=115, upsilon=2.5)
 

biometrics documentation built on March 20, 2026, 5:09 p.m.