lang.fx: Function to computes the result of the Curtis's allometric...

View source: R/lang.r

lang.fxR Documentation

Function to computes the result of the Curtis's allometric model.

Description

Function of the Langhmuir model, based upon two parameters, and a single predictor variable, as follows

y_i= \alpha \left(\frac{1}{1+\frac{1}{\beta x_i}}\right),

where: y_i and x_i are the response and predictor variable, respectively, for the i-th observation; and the rest are parameters (i.e., coefficients). Further details of this function can be found in Salas-Eljatib (2025).

Usage

lang.fx(x, alpha, beta, upsilon = 0)

Arguments

x

is the predictor variable.

alpha

is the coefficient-parameter \alpha.

beta

is the coefficient-parameter \beta.

upsilon

is an optional constant term that force the prediction of y when x=0. Thus, the new model becomes y_i = \Upsilon+ f(x_i,\mathbf{\theta}), where \mathbf{\theta} is the vector of coefficients of the above described function represented by f(\cdot). The default value for \Upsilon is 0.

Value

Returns the response variable based upon the predictor variable and the coefficients.

Author(s)

Christian Salas-Eljatib.

References

  • Khayyun TS, Mseer AH. 2019. Comparison of the experimental results with the Langmuir and Freundlich models for copper removal on limestone adsorbent. Applied Water Science 9(8):170.

  • Salas-Eljatib C. 2025. Funciones alométricas: reparametrizaciones y características matemáticas. Documento de trabajo No. 1, Serie: Cuadernos de biometría, Laboratorio de Biometría y Modelación Forestal, Universidad de Chile. Santiago, Chile. 51 p. https://biometriaforestal.uchile.cl

Examples

# Predictor variable values to be used
time<-seq(.1,60,by=0.01)
# Using the function
y<-lang.fx(x=time, alpha=37,beta=0.05)
plot(time,y,type="l")
 

biometrics documentation built on March 20, 2026, 5:09 p.m.