| largeplot | R Documentation |
Data from a large (8.8 ha) fully mapped plot in a Norway spruce (Picea abies) dominated old-growth forest in the subarctic region of Fennoscandia.
data(largeplot)
Contains Cartesian position of trees and other variables in a large sample plot, as follows:
Tree ID.
Species code as follows: 1=Pinus sylvestris,2=Picea abies,3=Betula pubescens, 5=Salix caprea, 8: Sorbus aucuparia.
Cartesian position in the X-axis, in m.
Cartesian position in the Y-axis, in m.
Measurement year.
Diameter at breast-height, in cm.
Total height, in m.
Data were retrieved from the paper cited below, where several details might be worth reading.
Pouta P, Kulha N, Kuuluvainen T, Aakala T. 2022. Partitioning of space among trees in an old-growth spruce forest in subarctic Fennoscandia. Frontiers in Forests and Global Change 5: 817248. \Sexpr[results=rd]{tools:::Rd_expr_doi("https://doi.org/10.3389/ffgc.2022.817248")}
data(largeplot)
head(largeplot)
df<-largeplot
pine <- df[df$spp.code==1,]
spruce <- df[df$spp.code==2,]
birch <- df[df$spp.code==3,]
plot(spruce$x.coord,spruce$y.coord,cex=(spruce$dbh)/30,col="blue")
points(birch$x.coord,birch$y.coord,cex=(birch$dbh)/30,col="green")
points(pine$x.coord,pine$y.coord,cex=(pine$dbh)/30,col="red")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.