logistm.fx: A function having the mathematical expression of
the Logistic modified model.
Description
Function of the Logistic modified model, based
upon three parameters and a single predictor variable as
follows
$$y_i= \frac{\alpha}{1+\mathrm{e}^{-\left(x_i-\beta \right)/\gamma}},$$
where: \(y_i\) and \(x_i\) are the response
and predictor variable, respectively, for the i-th observation;
and the rest are parameters (i.e., coefficients).
Usage
logistm.fx(x, a = alpha, b = beta, c = gamma, phi = 0)
Value
Returns the response variable based upon
the predictor variable and the coefficients.
Arguments
x
is the predictor variable.
a
is the coefficient-parameter \(\alpha\).
b
is the coefficient-parameter \(\beta\).
c
is the coefficient-parameter \(\gamma\).
phi
is an optional constant term that force the prediction
of y when x=0. Thus, the new model becomes
\( y_i = \phi+ f\left(x_i,\mathbf{\theta}\right)\), where
\(\mathbf{\theta}\) is the vector of coefficients of
the above described function represented by
\(f(\cdot)\). The default
value for \(\phi\) is 0.
Author
Christian Salas-Eljatib.
References
Pearl R. 1909. Some recent studies on growth. The American
Naturalist 43(509):302-316.
Pinheiro JC, DM Bates. 2000. Mixed-effects Models in S and
Splus. New York, USA. Springer-Verlag. 528 p.
Salas-Eljatib C. 2025. Funciones alométricas: reparametrizaciones
y características matemáticas. Documento de trabajo No. 1,
Serie: Cuadernos de biometría, Laboratorio de Biometría y
Modelación Forestal, Universidad de Chile. Santiago, Chile. 51 p.
https://biometriaforestal.uchile.cl