mmenten.fx: A function having the mathematical expression of the...

View source: R/mmenten.r

mmenten.fxR Documentation

A function having the mathematical expression of the Michaelis-Menten model.

Description

Function of the Michaelis-Menten model, based upon two parameters and a single predictor variable as follows

y_i= \alpha \left(\frac{x_i}{\beta+x_i} \right),

where: y_i and x_i are the response and predictor variable, respectively, for the i-th observation; and the rest are parameters (i.e., coefficients).

Usage

mmenten.fx(x, alpha, beta, upsilon = 0)

Arguments

x

is the predictor variable.

alpha

is the coefficient-parameter \alpha.

beta

is the coefficient-parameter \beta.

upsilon

is an optional constant term that force the prediction of y when x=0. Thus, the new model becomes y_i = \Upsilon+ f(x_i,\mathbf{\theta}), where \mathbf{\theta} is the vector of coefficients of the above described function represented by f(\cdot). The default value for \Upsilon is 0.

Value

Returns the response variable based upon the predictor variable and the coefficients.

Author(s)

Christian Salas-Eljatib.

References

  • Michaelis L, ML Menten. 1913. Die kinetik der invertinwirkung. Biochemische Zeitschrift 49:333–369.

  • Salas-Eljatib C, P Corvalán, N Pino, PJ Donoso, DP Soto.

  1. Modelos de efectos mixtos de altura-diámetro para Drimys winteri en el sur (41-43 S) de Chile. Bosque 40(1):71-80.

  • Salas-Eljatib C. 2025. Funciones alométricas: reparametrizaciones y características matemáticas. Documento de trabajo No. 1, Serie: Cuadernos de biometría, Laboratorio de Biometría y Modelación Forestal, Universidad de Chile. Santiago, Chile. 51 p. https://biometriaforestal.uchile.cl

Examples

# Predictor variable values to be used
time<-seq(5,60,by=0.01)
# Using the function
y<-mmenten.fx(x=time,alpha=30,beta=13)
plot(time,y,type="l")
 

biometrics documentation built on March 20, 2026, 5:09 p.m.