mmweibull: Function to estimates the parameters of the Weibull...

View source: R/mmweibull.r

mmweibullR Documentation

Function to estimates the parameters of the Weibull probability density function using the method of moments

Description

Estimates the parameters of the Weibull probability density function based on the method of moments. It is based on the 2-parameter reparemetrization of the function, i.e., the shape and scale parameters.

Usage

mmweibull(y)

Arguments

y

a vector having the randon variable values.

Details

Althought the original function was written by Dr Oscar García, and the corresponding reference is provided, the current function has some changes to make it of a broader use.

Value

The main output is a list with the two estimated parameters and the number of observations being used for estimating the parameters.

Author(s)

Dr Oscar García and Christian Salas-Eljatib.

References

  • García, O. 1981. Simplified method-of-moments estimation for the Weibull distribution. New Zealand Journal of Forestry Science 11(3): 304-306.

Examples


# Random variable to be studied
library(datana)
yvar<-llancahue$dbh
summary(yvar)
hist(yvar)
# Using the  function
mmweibull(y=yvar)

biometrics documentation built on March 20, 2026, 5:09 p.m.