| pinusSpp | R Documentation |
These are tree-lavel measurement data from Pinus spp invasion in Araucaria-Nothofagus forests in the Malalcahuello National Reserve in La Araucanía region in southhern Chile, measured in 2012. There are 26 plots and plot size is 100 m².
data(pinusSpp)
Contains eight variables, as follows:
Plot sample ID.
Plot size, en m^{2}.
Decimal coordinate of S latitude.
Decimal coordinate of W longitude.
Tree identificator number in each plot. Same indv.id for
multi-stem trees.
Stem identificator number in each plot.
Species.
Diameter at breast-height, in cm.
Total height, in m.
Height to crown base, in m.
Crown lenght, in m.
The data is provided courtesy of Drs. Aníbal Pauchard and Rafael García at the Laboratorio de Invasiones Biológicas, Universidad de Concepción (Concepción, Chile).
Cobar-Carranza A, Garcia R, Pauchard A, Pena E. 2014. Effect of Pinus contorta invasion on forest fuel properties and its potential implications on the fire regime of Araucaria araucana and Nothofagus antarctica forests. Biological Invasions. 16(11): 2273-2291. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1007/s10530-014-0663-8")}
data(pinusSpp)
head(pinusSpp)
length(unique(pinusSpp$plot.id))
boxplot(dbh~plot.id, data=pinusSpp)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.