prodan.fx: A function having the mathematical expression of the Naslund...

View source: R/prodan.r

prodan.fxR Documentation

A function having the mathematical expression of the Naslund model.

Description

Function of the Naslund model, based upon three parameters and a single predictor variable as follows

y_i= \frac{x_i^2}{\left(\alpha + \beta x_i \right)^{2}},

where: y_i and x_i are the response and predictor variable, respectively, for the i-th observation; and the rest are parameters (i.e., coefficients).

Usage

prodan.fx(x, alpha, beta, gamma, upsilon = 0)

Arguments

x

is the predictor variable.

alpha

is the coefficient-parameter \alpha.

beta

is the coefficient-parameter \beta.

gamma

is the coefficient-parameter \gamma.

upsilon

is an optional constant term that force the prediction of y when x=0. Thus, the new model becomes y_i = \Upsilon+ f\left(x_i,\mathbf{\theta}\right), where \mathbf{\theta} is the vector of coefficients of the above described function represented by f(\cdot). The default value for \Upsilon is 0.

Value

Returns the response variable based upon the predictor variable and the coefficients.

Author(s)

Christian Salas-Eljatib.

References

  • Näslund M. 1947. Skogsförsöksanstaltens gallringsförsök i tallskog. Technical report. Biochemische Zeitschrift 49:333–369.

  • Salas-Eljatib C. 2025. Funciones alométricas: reparametrizaciones y características matemáticas. Documento de trabajo No. 1, Serie: Cuadernos de biometría, Laboratorio de Biometría y Modelación Forestal, Universidad de Chile. Santiago, Chile. 51 p. https://biometriaforestal.uchile.cl

Examples

# Predictor variable values to be used
time<-seq(5,60,by=0.01)
# Using the function
y<-prodan.fx(x=time,alpha=2.06,beta=.41,gamma=.03)
plot(time,y,type="l")
 

biometrics documentation built on March 20, 2026, 5:09 p.m.