radiatapl: Sampling plots data from a Pinus radiata plantation near...

radiataplR Documentation

Sampling plots data from a Pinus radiata plantation near Capitán Pastene, La Araucanía region, Chile.

Description

Tree-level information collected within sample plots in a forestry 13 years-old plantation of Pinus radiata near Capitán Pastene, Southern Chile. The sample plots size is 150 m², and the total area of the plantation is 45 ha.

Usage

data(radiatapl)

Format

The data frame contains four variables as follows:

plot

Plot number identification.

tree

Tree number identification.

dbh

Diameter at breast height (1.3 m), in cm.

heigth

Total height, in m. Not measured for all trees.

sanity

Tree-health clasification, assigned to any of the following levels: good, medium, and bad.

The data are provided courtesy of Mr. Mauricio Lobos-Beneventi (Temuco, Chile), and were collected with the help of his colleague, Christian Salas-Eljatib.

Examples

data(radiatapl)
head(radiatapl)

biometrics documentation built on March 20, 2026, 5:09 p.m.