schnute.fx: Function that computes the result of the Schnute allometric...

View source: R/schnute.r

schnute.fxR Documentation

Function that computes the result of the Schnute allometric model.

Description

Function of the Schnute allometric model, based upon parameters (i.e., coefficients) and a variable, as defined by the mathematical expression

y_i=\left\{\Upsilon^{\alpha}+(\gamma^{\alpha}-\Upsilon^{\alpha}) \frac{1-\mathrm{e}^{-\beta(x_i)}}{1-\mathrm{e}^{-\beta(x_2)}} \right \}^{1/\alpha},

where: y_i and x_i are the response and predictor variable, respectively, for the i-th observation; and the rest are parameters (i.e., coefficients). Further details on this function can be found in Salas-Eljatib et al (2021).

Usage

schnute.fx(x, alpha, beta, gamma, upsilon = 0, x1 = min(x), x2 = max(x))

Arguments

x

is the predictor variable.

alpha

is the coefficient-parameter \alpha.

beta

is the coefficient-parameter \beta.

gamma

is the coefficient-parameter \gamma.

upsilon

is an optional constant term that force the prediction of y when x=0. The default value for \Upsilon is 0.

x1

is the minimum value for the x variable. The default value is internally computed from the sample.

x2

is the maximumvalue for the x variable. The default value is internally computed from the sample.

Value

Returns the response variable based upon the predictor variable and the coefficients.

Author(s)

Christian Salas-Eljatib.

References

  • Schnute I. 1981. A versatile growth model with statistically stable parameters. Can. J. Fish. Aquat. Sci. 38(9):1128-1140.

  • Salas-Eljatib C. 2025. Funciones alométricas: reparametrizaciones y características matemáticas. Documento de trabajo No. 1, Serie: Cuadernos de biometría, Laboratorio de Biometría y Modelación Forestal, Universidad de Chile. Santiago, Chile. 51 p. https://biometriaforestal.uchile.cl

Examples

# Predictor variable values to be used
d<-seq(5,60,by=0.01)
# Using the function
h<-schnute.fx(x=d,alpha=1.77,beta=0.01,gamma=28)
plot(d,h,type="l")
 

biometrics documentation built on March 20, 2026, 5:09 p.m.