Learn R Programming

biometrics (version 1.0.3)

spatimepsp: Temporal tree locations within a sample plot in the Vienna woods

Description

The Austrian Research Center for Forests established a spacing experiment with Norway spruce (Picea abies) in the Vienna Woods. In the ``Hauersteig'' experiment, several tree-level variables were measured within four sample plots over time.

Usage

data(spatimepsp)

Arguments

Format

Contains cartesian position of trees, and covariates, in a sample plot, as follows:

plot

Plot number.

tree

Tree number.

species

Species code as follows: PCAB=Picea abies, LADC=Larix decidua, PNSY=Pinus sylvestris, FASY=Fagus Sylvatica, QCPE=Quercus petraea, BTPE=Betula pendula.

x.coord

Cartesian position in the X-axis, in m.

y.coord

Cartesian position in the Y-axis, in m.

year

Measurement year.

dbh

diameter at breast-height, in cm.

References

  • Kindermann G. Kristofel F, Neumann M, Rossler G, Ledermann T & Schueler. 2018. 109 years of forest growth measurements from individual Norway spruce trees. Sci. Data 5:180077 tools:::Rd_expr_doi("10.1038/sdata.2018.77")

Examples

Run this code
data(spatimepsp)
head(spatimepsp)
df<-spatimepsp
lattice::xyplot(y.coord~x.coord|as.factor(year),
data=df,as.table=TRUE)

Run the code above in your browser using DataLab