| stage.fx | R Documentation |
Function of the Stage allometric model, based upon parameters (i.e., coefficients) and a variable, as defined by the mathematical expression
y_i= \alpha
\mathrm{e}^{\left(-\beta ({x_i}^{-\gamma}) \right)},
where: y_i and x_i are the response
and predictor variable, respectively, for the i-th observation;
and the rest are parameters (i.e., coefficients).
Further details on this function can be found in
Salas-Eljatib (2025).
stage.fx(x, alpha, beta, gamma, upsilon = 0)
x |
is the predictor variable. |
alpha |
is the coefficient-parameter |
beta |
is the coefficient-parameter |
gamma |
is the coefficient-parameter |
upsilon |
is an optional constant term that force the prediction
of y when x=0. Thus, the new model becomes
|
Returns the response variable based upon the predictor variable and the coefficients.
Christian Salas-Eljatib.
Stage AR. 1963. A mathematical approach to polymorphic site index curves for Grand Fir. Forest Sci. 9(2):167-180. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1093/forestscience/9.2.167")}
Salas-Eljatib C. 2025. Funciones alométricas: reparametrizaciones y características matemáticas. Documento de trabajo No. 1, Serie: Cuadernos de biometría, Laboratorio de Biometría y Modelación Forestal, Universidad de Chile. Santiago, Chile. 51 p. https://biometriaforestal.uchile.cl
# Predictor variable values to be used
time<-seq(5,60,by=0.01)
# Using the function
d<-stage.fx(x=time,alpha=28,beta=56,gamma=1.19)
plot(time,d,type="l")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.