standtabCoihue: Stand table for a _Nothofagus dombeyi_ (coihue) forest

standtabCoihueR Documentation

Stand table for a Nothofagus dombeyi (coihue) forest

Description

Stand table for a secondary forest of Nothofagus dombeyi (coihue) en Chile.

Usage

data(standtabCoihue)

Format

The data has the following columns

diam.cl

Diameter class, in cm.

nha

Density for the respective diameter class, in trees/ha.

gha

Basal area for the respective diameter class, in m^{2}/ha.

The forest was located in the Andean foothills in the Araucanía region in southern Chile. Data from Prof. Christian Salas-Eljatib, Universidad de Chile, Santiago, Chile.

References

  • Donoso C. 1995. Bosques Templados de Chile y Argentina. Editorial Universitaria. Santiago, Chile.

Examples

data(standtabCoihue)
df<-standtabCoihue
df<-df[-nrow(df),]
# Diameter distribution plot 
barplot(df$nha, legend = TRUE, beside = TRUE, las=1,
        names.arg = as.numeric(df$diam.cl),
        ylab="Density (trees/ha)",xlab="Diameter class (cm)")
abline(h=0)

biometrics documentation built on March 20, 2026, 5:09 p.m.