standtabRauli: Stand tables for _Nothofagus alpina_ (raulí) forests

standtabRauliR Documentation

Stand tables for Nothofagus alpina (raulí) forests

Description

Stand tables for secondary Nothofagus alpina-dominated forests in different locations in southern Chile.

Usage

data(standtabRauli)

Format

The data has the following columns

site

Study site.

sector

Location within a study site.

low.cd

Lower limit of the diameter class, in cm.

upp.cd

Upper limit of the diameter class, in cm.

dclass

Diameter class, in cm.

nha.dcl

Tree density for the respective diameter class, in trees/ha.

forest.id

Forest ID code, a combination of columns site and sector.

Tree density by diameter classes (i.e., stand table). Data were digitized from table No. 4 of Wadsworth (1976).

References

  • Wadsworth RK. 1976. Aspectos ecologicos y crecimiento del raulí (Nothofagus alpina) y sus asociados en bosques de segundo crecimiento de las provincias de Bío-Bío, Malleco y Cautín, Chile. Boletin Técnico No. 37, Fac. Cs. Forestales, Universidad de Chile, Santiago, Chile.

Examples

data(standtabRauli)
head(standtabRauli)
df<-standtabRauli
table(df$site,df$sector,df$dclass)

biometrics documentation built on March 20, 2026, 5:09 p.m.