| strandg.fx | R Documentation |
Function of the Strand generalized model, based upon three parameters and a single predictor variable as follows
y_i= \left(\frac{x_i}{\alpha +\beta x_i}\right)^{\gamma},
where: y_i and x_i are the response
and predictor variable, respectively, for the i-th observation;
and the rest are parameters (i.e., coefficients).
strandg.fx(x, alpha, beta, gamma, upsilon = 0)
x |
is the predictor variable. |
alpha |
is the coefficient-parameter |
beta |
is the coefficient-parameter |
gamma |
is the coefficient-parameter |
upsilon |
is an optional constant term that force the prediction
of y when x=0. Thus, the new model becomes
|
Returns the response variable based upon the predictor variable and the coefficients.
Christian Salas-Eljatib.
Strand L. 1964. Numerical constructions of site-index curves. Forest Sci. 10(4):410-414.
Salas-Eljatib C. 2025. Funciones alométricas: reparametrizaciones y características matemáticas. Documento de trabajo No. 1, Serie: Cuadernos de biometría, Laboratorio de Biometría y Modelación Forestal, Universidad de Chile. Santiago, Chile. 51 p. https://biometriaforestal.uchile.cl
# Predictor variable values to be used
time<-seq(5,60,by=0.01)
# Using the function
y<-strandg.fx(x=time,alpha=0.98,beta=0.52,gamma=4.83)
plot(time,y,type="l")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.