thinningtrial: Stand variables by thinning treatment for secondary forests...

thinningtrialR Documentation

Stand variables by thinning treatment for secondary forests of Drymis winteri near Valdivia, Chile.

Description

The average of stand variables per thinning treatments applied to secondary forest of Drymis winteri in Hueicolla, in the Coastal range of Valdivia (Chile). Data are measurements carried out during 1986 and 1990. The thinning treatments are as follows: distance among trees of 2 m, 3 m, y 4 m; release thinning, and control (i.e., no thinning). The values are the mean of the following stand variables: density (trees/ha), basal area (^{2}/ha) and volume (^{3}/ha).

Usage

data(thinningtrial)

Format

The dataframe has the following columns:

treat

Thinning treatment: distance among trees of 2m, 3m, and 4m; release thinning; and control.

time

Year of measurement (1986 o 1990)

nha

Average density, in arb/ha.

gha

Average basal area, in m^{2}/ha

vha

Average volume, in m^{3}/ha.

Data were derived from the tables number 4, 6 and 7, of the paper of Navarro et al. (1997).

References

Navarro, C., Donoso, P., y Rosas, M. (1997). Crecimiento de renovales de Drymis winteri sometidos a distintos tratamientos de raleo. En: Donoso, C. (Ed.), Bosques templados de Chile y Argentina. Editorial Universitaria, Santiago de Chile.

Examples

data(thinningtrial)
head(thinningtrial)
df<-thinningtrial
require(lattice)
xyplot(nha~time|treat, data=df, type="b",as.table=TRUE)
xyplot(nha~time,groups=treat, data=df, type="b",auto.key = TRUE)
xyplot(gha~time|treat, data=df, type="b",as.table=TRUE)

biometrics documentation built on March 20, 2026, 5:09 p.m.