treegrowth: Diameter and height growth of Grand-fir sample trees.

treegrowthR Documentation

Diameter and height growth of Grand-fir sample trees.

Description

Diameter and height growth of 66 Grand-fir trees. Data derived from stem analysis sample trees collected by Dr. Albert Stage (US Forest Service, Moscow, ID, USA.)

Usage

data(treegrowth)

Format

Contains seven column, as follows:

tree.no

Tree number identificator. An unique number to each sample tree.

forest

Forest type.

habitat

Forest habitat type.

tree.code

A composite tree code representing the following columns: tree.id-forest-habitat

age

Age, in yr

dbh

Diameter at breast-height, in cm. Originally measured in inches, and was converted to cm using a single decimal.

toth

Total height, in m. Originally measured in feet, and was converted to m using a single decimal.

Originally, the data were provided by Dr. Albert Stage (R.I.P) to Professor Andrew Robinson (University of Idaho, USA), whom used them to explain the fitting of statistical models. Dr Christian Salas-Eljatib was a former graduate student of Statistics of Prof. Robinson at the Univ. of Idaho.

References

  • Stage, A. R., 1963. A mathematical approach to polymorphic site index curves for Grand fir. Forest Science 9 (2), 167–180.

Examples

data(treegrowth)
df<-treegrowth
head(df)
require(lattice)
xyplot(dbh~age, groups = tree.code,data=df, type="b")

biometrics documentation built on March 20, 2026, 5:09 p.m.