| wykoff.fx | R Documentation |
Function of the Wykoff model, based upon two parameters and a single predictor variable as follows
y_i= \mathrm{e}^{\left(\alpha+\frac{\beta}{x_i+1} \right)},
where: y_i and x_i are the response
and predictor variable, respectively, for the i-th
observation; and the rest are parameters (i.e., coefficients).
wykoff.fx(x, alpha, beta, upsilon = 0)
x |
is the predictor variable. |
alpha |
is the coefficient-parameter |
beta |
is the coefficient-parameter |
upsilon |
is an optional constant term that force the prediction
of y when x=0. Thus, the new model becomes
|
Returns the response variable based upon the predictor variable and the coefficients.
Christian Salas-Eljatib.
Wykoff WR, NL Crookston, AR Stage. 1982. User’s guide to the Stand Prognosis Model. USDA For. Serv. Gen. Tech. Rep. INT-133, USA. 112 p.
Salas-Eljatib C. 2025. Funciones alométricas: reparametrizaciones y características matemáticas. Documento de trabajo No. 1, Serie: Cuadernos de biometría, Laboratorio de Biometría y Modelación Forestal, Universidad de Chile. Santiago, Chile. 51 p. https://biometriaforestal.uchile.cl
# Predictor variable values to be used
d<-seq(5,60,by=0.01)
# Using the function
h<-wykoff.fx(x=d,alpha=3.87,beta=4.38,upsilon=1.3)
plot(d,h,type="l")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.