| asymreg.fx | R Documentation |
Function of the asymptotic regression model, based upon its parameters and a variable, as follows
y_i= \alpha +
\left(\beta-\alpha\right) \left\{\mathrm{e}^{
\left[-\left(\mathrm{e}^{-\gamma}\right) x_i \right]
}\right\},
where: y_i and x_i are the response
and predictor variable, respectively, for the i-th observation;
and the rest are parameters (i.e., coefficients).
asymreg.fx(x, alpha, beta, upsilon = 0)
x |
is the predictor variable. |
alpha |
is the coefficient-parameter |
beta |
is the coefficient-parameter |
upsilon |
is an optional constant term that force the prediction
of y when x=0. Thus, the new model becomes
|
Returns the response variable based upon the predictor variable and the coefficients.
Christian Salas-Eljatib.
Pinheiro JC, DM Bates. 2000. Mixed-effects Models in S and Splus. New York, USA. Springer-Verlag. 528 p.
Salas-Eljatib C. 2025. Funciones alométricas: reparametrizaciones y características matemáticas. Documento de trabajo No. 1, Serie: Cuadernos de biometría, Laboratorio de Biometría y Modelación Forestal, Universidad de Chile. Santiago, Chile. 51 p. https://biometriaforestal.uchile.cl
#---------------------
# 2-parameters variant
# Predictor variable values to be used
time<-seq(0,50,by=0.1)
# Using the function, upsilon must be provided
y<-asymreg.fx(x=time,alpha=20,beta=2.5,upsilon =5)
plot(time,y,type="l",ylim=c(0,20))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.