Function of the Bertalanffy-Richards model, based upon three parameters and a single predictor variable as follows $$y_i= \alpha \left(1-\mathrm{e}^{-\beta {x_i}}\right)^{1/\gamma}, $$ where: \(y_i\) and \(x_i\) are the response and predictor variable, respectively for the i-th observation; and the rest are parameters (i.e., coefficients).
bertarich.fx(x, a = alpha, b = beta, c = gamma, phi = 0)Returns the response variable based upon the predictor variable and the coefficients.
is the predictor variable.
is the coefficient-parameter \(\alpha\).
is the coefficient-parameter \(\beta\).
is the coefficient-parameter \(\gamma\).
is an optional constant term that force the prediction of y when x=0. Thus, the new model becomes \( y_i = \phi+ f(x_i,\mathbf{\theta})\), where \(\mathbf{\theta}\) is the vector of coefficients of the above described function represented by \(f(\cdot)\). The default value for \(\phi\) is 0.
Christian Salas-Eljatib.
Richards FJ. 1959. A flexible growth function for empirical use. J. of Experimental Botany 10(29):290-300.
von Bertalanffy L. 1957. Quantitative laws in metabolism and growth. The Quarterly Review of Biology 32(3):217-231.
Salas-Eljatib C. 2020. Height growth-rate at a given height: a mathematical perspective for forest productivity. Ecological Modelling 431:109198. tools:::Rd_expr_doi("10.1016/j.ecolmodel.2020.109198") https://eljatib.com/myPubs/2020hgrate_ecoModelling.pdf
Salas-Eljatib C, Mehtatalo L, Gregoire TG, Soto DP, Vargas-Gaete R. 2021. Growth equations in forest research: mathematical basis and model similarities. Current Forestry Reports 7:230-244. tools:::Rd_expr_doi("10.1007/s40725-021-00145-8")
Salas-Eljatib C. 2025. Funciones alométricas: reparametrizaciones y características matemáticas. Documento de trabajo No. 1, Serie: Cuadernos de biometría, Laboratorio de Biometría y Modelación Forestal, Universidad de Chile. Santiago, Chile. 51 p. https://biometriaforestal.uchile.cl
# Predictor variable values to be used
time<-seq(5,60,by=0.01)
# Using the function
y<-bertarich.fx(x=time,a=23,b=0.08,c=0.89)
plot(time,y,type="l")
Run the code above in your browser using DataLab