Learn R Programming

biometrics (version 1.0.3)

biging.fx: Taper equation by Biging

Description

Tree taper equation proposed by Biging (1984), that depends on model parameters and tree size variables: diameter, total height, and stem height. The mathematical model is:

$$ d_{l_i} = d_i ( \beta_0 + \beta_1 ln(1 - \lambda (h_{l_i} / h_i )^\frac{1}{3})) $$

where: \(d_{l_i}\) is the stem diameter at stem-height \(h_{l_i}\) for the i-th tree; \(d_i\) and \(h_i\) are the tree-level variables diameter at breast height and total height, respectively, and

$$ \lambda = 1 - e^{(\frac{-\beta_0}{\beta_1})} $$

Usage

biging.fx(d, hl, h, paramod)

Value

Returns the diameter of the stem at the stem-height \(h_l\), thus \(d_l\), for the Biging (1984) functional form, based upon tree diameter \(d\) and total height \(h\).

Arguments

d

is the diameter at breast height (1.3 m) of the tree. The measurement unit is cm in the metric system, but ultimately it will depend on how the model was previously fitted, because of the measurement unit of the variables included.

hl

hl is stem height within the tree, thus \(h_l \leq h\).

h

is total height of the tree.

paramod

paramod is a vector having the coefficients of the model in the following order: \(\beta_0\), \(\beta_1\).

References

  • Biging GS. 1984. Taper equations for second-growth mixed conifers of northern California. Forest Science 30(4): 1103–1117. tools:::Rd_expr_doi("10.1093/forestscience/30.4.1103")

Examples

Run this code
## Parameters
b0 <- 1.016215
b1 <- 0.332529
coefs <- c(b0, b1)

## Tree attributes
dbh <- 40
toth <- 25

## Using the function
hl.int <- c(0.3, 1.3, 5)
dl.hat <- biging.fx(d = dbh, h = toth, hl = hl.int, paramod=coefs)
cbind(hl.int, dl.hat)

Run the code above in your browser using DataLab