curtis.fx: Function to computes the result of the Curtis's allometric
model.
Description
Function of the traditional Curtis' allometric model, based
upon two parameters, and a single predictor variable as
follows
$$y_i= \alpha \left(\frac{x_i}{1+x_i} \right)^{\beta},$$
where: \(y_i\) and \(x_i\) are the response
and predictor variable, respectively for the i-th observation;
and the rest are parameters (i.e., coefficients).
Usage
curtis.fx(x, a = alpha, b = beta, phi = 0)
Value
Returns the response variable based upon
the predictor variable and the coefficients.
Arguments
x
is the predictor variable.
a
is the coefficient-parameter \(\alpha\).
b
is the coefficient-parameter \(\beta\).
phi
is an optional constant term that force the prediction
of y when x=0. Thus, the new model becomes
\( y_i = \phi+ f(x_i,\mathbf{\theta})\), where
\(\mathbf{\theta}\) is the vector of coefficients of
the above described function represented by
\(f(\cdot)\). The default
value for \(\phi\) is 0.
Author
Christian Salas-Eljatib.
References
Curtis RO. 1967. Height-diameter and height-diameter-age
equations for second-growth Douglas-fir. Forest Sci. 13(4):365-375.
Salas-Eljatib C. 2025. Funciones alométricas: reparametrizaciones
y características matemáticas. Documento de trabajo No. 1,
Serie: Cuadernos de biometría, Laboratorio de Biometría y
Modelación Forestal, Universidad de Chile. Santiago, Chile. 51 p.
https://biometriaforestal.uchile.cl