Learn R Programming

biometrics (version 1.0.3)

curtisori.fx: Function to computes the result of the original Curtis's allometric model.

Description

Function of the originally proposed allometric model by Curtis, based upon two parameters, and a single predictor variable as follows $$y_i= \frac{x_i}{\alpha +\beta x_i},$$ where: \(y_i\) and \(x_i\) are the response and predictor variable, respectively for the i-th observation; and the rest are parameters (i.e., coefficients). Please read the details on this model in Salas-Eljatib (2025).

Usage

curtisori.fx(x, a = alpha, b = beta, phi = 0)

Value

Returns the response variable based upon the predictor variable and the coefficients.

Arguments

x

is the predictor variable.

a

is the coefficient-parameter \(\alpha\).

b

is the coefficient-parameter \(\beta\).

phi

is an optional constant term that force the prediction of y when x=0. Thus, the new model becomes \( y_i = \phi+ f(x_i,\mathbf{\theta})\), where \(\mathbf{\theta}\) is the vector of coefficients of the above described function represented by \(f(\cdot)\). The default value for \(\phi\) is 0.

Author

Christian Salas-Eljatib.

References

  • Curtis RO. 1967. Height-diameter and height-diameter-age equations for second-growth Douglas-fir. Forest Sci. 13(4):365-375.

  • Salas-Eljatib C. 2025. Funciones alométricas: reparametrizaciones y características matemáticas. Documento de trabajo No. 1, Serie: Cuadernos de biometría, Laboratorio de Biometría y Modelación Forestal, Universidad de Chile. Santiago, Chile. 51 p. https://biometriaforestal.uchile.cl

Examples

Run this code
# Parameters
# Predictor variable values to be used
time<-seq(5,60,by=0.01)
# Using the function
y<-curtisori.fx(x=time,a=20,b=8)
plot(time,y,type="l")
 

Run the code above in your browser using DataLab