| cwd | R Documentation |
These are log-level variables measured in the field in a single line intersect sampling (LIS) unit. The length of the line or transect is 30 m. Details on this type of sampling strategy can be reviewed in Gregoire and Valentine (2008).
cwd
Data contains the following columns:
Element (i.e., log) number with the LIS sample.
Diameter of the element, in cm.
Length, in m.
Angle of the element with respect to the line sampling, in degrees.
Data from Marshall et al 2000.
Marshall PL, G Davis, VM LeMay. 2000. Using line intersect sampling for coarse woody debris. Technical Report 3, British Columbia Forest Service, Nanaimo, BC, Canada. 34 p.
Gregoire TG, HT Valentine. 2008. Sampling Strategies for Natural Resources and the Environment. New York, USA. Chapman & Hall/CRC. 474 p.
data(cwd)
cwd
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.