| dg.fx | R Documentation |
Function to compute the diameter of the tree of average basal
area (D_{\overline{g}}),
which depends on stand density (N) and stand basal area (G).
The aforementioned stand diameter is computed as
D_{\overline{g}} = \sqrt{ \frac{G}{N} \frac{k}{pi}}
where the constant k depends on whether the variables are in the
units of measurement of the metric or imperial system.
dg.fx(n = n, g = g, metrics = TRUE)
n |
is stand tree density. By default the unit of measurement
is trees/ha, but if the option 'metrics' is set to |
g |
is stand basal area. By default the unit of measurement
must be entered in m |
metrics |
is a logic value, the default is set to |
Returns the diameter of the tree of average basal area.
Christian Salas-Eljatib.
##Using the function
dg.fx(n=1000, g=55)
dg.fx(n=210, g=160, metrics=FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.