Learn R Programming

biometrics (version 1.0.3)

dg.fx: Function to computes the diameter of the tree of average basal area.

Description

Function to compute the diameter of the tree of average basal area (\(D_{\overline{g}}\)), which depends on stand density (\(N\)) and stand basal area (\(G\)). The aforementioned stand diameter is computed as $$D_{\overline{g}} = \sqrt{ \frac{G}{N} \frac{k}{pi}}$$ where the constant \(k\) depends on whether the variables are in the units of measurement of the metric or imperial system.

Usage

dg.fx(n = n, g = g, metrics = TRUE)

Value

Returns the diameter of the tree of average basal area.

Arguments

n

is stand tree density. By default the unit of measurement is trees/ha, but if the option 'metrics' is set to FALSE, the unit is trees/acre.

g

is stand basal area. By default the unit of measurement must be entered in m\(^{2}\)/ha, but if the option 'metrics' is set to FALSE, the unit must be ft\(^{2}\)/ha.

metrics

is a logic value, the default is set to TRUE, thus both variables must be entered in the metric system, i.e., \(N\) in 'trees/ha', and \(G\) in m\(^{2}\)/ha. If metrics is FALSE, \(N\) must be in trees/acre, and \(G\) in ft\(^{2}\)/acre.

Author

Christian Salas-Eljatib.

Examples

Run this code

##Using the function
dg.fx(n=1000, g=55)
dg.fx(n=210, g=160, metrics=FALSE)

Run the code above in your browser using DataLab