Learn R Programming

biometrics (version 1.0.3)

eucaplot: Tree-level data from a sample plot established in a Eucalyptus globulus plantation

Description

Tree-level variables collected for all trees (even the variable height) within a sample plot in a forestry plantation of Eucalyptus globulus near Gorbea, southern Chile. The plot size is 500 m\(^{2}\). The plantation is 15 yr-old and had been subject to three thinnings.

Usage

data(eucaplot)

Arguments

Format

The dataframe contains four variables as follows:

dbh

Diameter at breast height, in cm.

health

health status (1: good, 2: medium, 3: bad).

shape

stem shape for timber purposes (1: good, 2: medium, 3: bad).

crown.class

Crown class (1: superior, 2: intermedium, 3: lower).

toth

Total height, in m.

References

  • Forest biometrics lecture notes, Prof. Christian Salas-Eljatib, Universidad de Chile. Santiago, Chile

Examples

Run this code
data(eucaplot)    
table(eucaplot$health)
library(datana) 
descstat(eucaplot[,c("dbh","toth")])

Run the code above in your browser using DataLab