| eucaplotr | R Documentation |
Tree-level variables collected in a sample plot (area=500 m^{2})
in a forestry plantation of Eucalyptus globulus near Gorbea, in southern
Chile. The variable height, was only measured in a sub-sample of
trees within the plot. The plantation is 15 yr-old and had been subject to
three thinnings.
data(eucaplotr)
The dataframe contains four variables as follows:
Diameter at breast height, in cm.
health status (1: good, 2: medium, 3: bad).
stem shape for timber purposes (1: good, 2: medium, 3: bad).
Crown class (1: superior, 2: intermedium, 3: lower).
Total height (in m), only available for some trees.
Otherwise missing values are denoted by NA.
The data were provided courtesy of Dr Christian Salas-Eljatib (Universidad de Chile, Santiago, Chile).
Forest biometrics lecture notes, Prof. Christian Salas-Eljatib, Universidad de Chile. Santiago, Chile
data(eucaplotr)
table(eucaplotr$shape)
library(datana)
descstat(eucaplotr[,c("dbh","toth")])
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.