Learn R Programming

biometrics (version 1.0.3)

eucaplotr: Tree-list (realistic-) data in a sample plot established in a Eucalyptus globulus plantation in southern Chile.

Description

Tree-level variables collected in a sample plot (area=500 m\(^{2}\)) in a forestry plantation of Eucalyptus globulus near Gorbea, in southern Chile. The variable height, was only measured in a sub-sample of trees within the plot. The plantation is 15 yr-old and had been subject to three thinnings.

Usage

data(eucaplotr)

Arguments

Format

The dataframe contains four variables as follows:

dbh

Diameter at breast height, in cm.

health

health status (1: good, 2: medium, 3: bad).

shape

stem shape for timber purposes (1: good, 2: medium, 3: bad).

crown.class

Crown class (1: superior, 2: intermedium, 3: lower).

toth

Total height (in m), only available for some trees. Otherwise missing values are denoted by NA.

References

  • Forest biometrics lecture notes, Prof. Christian Salas-Eljatib, Universidad de Chile. Santiago, Chile

Examples

Run this code
data(eucaplotr)    
table(eucaplotr$shape)
library(datana) 
descstat(eucaplotr[,c("dbh","toth")])

Run the code above in your browser using DataLab