gompertz.fx: Function to compute the result of the Gompertz
allometric model.
Description
Function of the Gompertz model, depending on
its three parameters and a variable, defined by the following
mathematical expression
$$y_i= \alpha
\mathrm{e}^{\left(-\beta \mathrm{e}^{-\gamma x_i} \right)},
$$
where: \(y_i\) and \(x_i\) are the response
and predictor variable, respectively for the i-th observation;
and the rest are parameters (i.e., coefficients).
Usage
gompertz.fx(x, a = alpha, b = beta, c = gamma, phi = 0)
Value
Returns the response variable based upon
the predictor variable and the coefficients.
Arguments
x
is the predictor variable.
a
is the coefficient-parameter \(\alpha\).
b
is the coefficient-parameter \(\beta\).
c
is the coefficient-parameter \(\gamma\).
phi
is an optional constant term that force the prediction
of y when x=0. Thus, the new model becomes
\( y_i = \phi+ f(x_i,\mathbf{\theta})\), where
\(\mathbf{\theta}\) is the vector of coefficients of
the above described function represented by
\(f(\cdot)\). The default
value for \(\phi\) is 0.
Author
Christian Salas-Eljatib.
References
Gompertz B. 1825. On the nature of the function expressive of
the law of human mortality, and on a new mode of determining the
value of life contingencies. Philosophical Transactions of the
Royal Society of London 115:513–583.
Salas-Eljatib C, Mehtatalo L, Gregoire TG, Soto DP,
Vargas-Gaete R. 2021. Growth equations in forest research:
mathematical basis and model similarities. Current
Forestry Reports 7:230-244. tools:::Rd_expr_doi("10.1007/s40725-021-00145-8")
Salas-Eljatib C. 2025. Funciones alométricas: reparametrizaciones
y características matemáticas. Documento de trabajo No. 1,
Serie: Cuadernos de biometría, Laboratorio de Biometría y
Modelación Forestal, Universidad de Chile. Santiago, Chile. 51 p.
https://biometriaforestal.uchile.cl