| gtree | R Documentation |
The function computes the basal area of a tree (g),
which only depends on its diameter at breast-height (d).
The basal area of a tree is computed as
g = \left(\frac{\pi}{k}\right) d^{2}
where the constant k depends on whether the diameter
and the resulting basal area are in the units of
the metric or imperial system.
gtree(x, metric = TRUE)
x |
is the object (i.e., vector or scalar) having tree diameter. By default the function assumes that the unit of measurement of this variable is cm. |
metric |
is a logic value, the default is to |
The value of basal area in m^{2} or in ft^{2},
depending on the units of measurement being defined.
Christian Salas-Eljatib
#Using the function
gtree(40)
gtree(x=30)
gtree(x=11.81,metric=FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.