| interpy2 | R Documentation |
X and Y), when the second element of Y is missing.A simple linear interpolation function applicable to two vectors
(e.g., X and Y) of length three, suitable when the second
element of Y is missing.
interpy2(xs = xs, ys = ys)
xs |
A numeric vector of length 3. |
ys |
A numeric vector of length 3, with the second position empty. |
The interpolated value for the second element of vector Y.
Christian Salas-Eljatib.
x<-c(0.2,0.8,1.3)
y<-c(48,NA,41)
interpy2(xs=x,ys=y)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.