interpy2: A simple linear interpolation function applicable to two vectors
(\(X\) and \(Y\)), when the second element of \(Y\) is missing.
Description
A simple linear interpolation function applicable to two vectors
(e.g., \(X\) and \(Y\)) of length three, suitable when the second
element of \(Y\) is missing.
Usage
interpy2(xs = xs, ys = ys)
Value
The interpolated value for the second element of vector \(Y\).
Arguments
xs
A numeric vector of length 3.
ys
A numeric vector of length 3, with the second position empty.