| inv.fx | R Documentation |
Function of the inverse model, based upon its two parameters and a variable, as follows
y_i = \alpha - \left(\frac{\beta}{x_i}\right),
where: y_i and x_i are the response
and predictor variable, respectively for the i-th observation;
and the rest are parameters (i.e., coefficients).
inv.fx(x, alpha, beta, upsilon = 0)
x |
is the predictor variable. |
alpha |
is the coefficient-parameter |
beta |
is the coefficient-parameter |
upsilon |
is an optional constant term that force the prediction
of y when x=0. Thus, the new model becomes
|
Returns the response variable based upon the predictor variable and the coefficients.
Christian Salas-Eljatib.
Salas-Eljatib C. 2025. Funciones alométricas: reparametrizaciones y características matemáticas. Documento de trabajo No. 1, Serie: Cuadernos de biometría, Laboratorio de Biometría y Modelación Forestal, Universidad de Chile. Santiago, Chile. 51 p. https://biometriaforestal.uchile.cl
# Predictor variable to be used is 40
# Using the function
inv.fx(x=40,alpha=25,beta=115)
# The effect of the constant term phi
inv.fx(x=40,alpha=25,beta=115, upsilon=2.5)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.