Learn R Programming

biometrics (version 1.0.3)

inv.fx: Function to compute the result of the simple linear inverse model.

Description

Function of the inverse model, based upon its two parameters and a variable, as follows $$ y_i = \alpha - \left(\frac{\beta}{x_i}\right),$$ where: \(y_i\) and \(x_i\) are the response and predictor variable, respectively for the i-th observation; and the rest are parameters (i.e., coefficients).

Usage

inv.fx(x, a = alpha, b = beta, phi = 0)

Value

Returns the response variable based upon the predictor variable and the coefficients.

Arguments

x

is the predictor variable.

a

is the coefficient-parameter \(\alpha\).

b

is the coefficient-parameter \(\beta\).

phi

is an optional constant term that force the prediction of y when x=0. Thus, the new model becomes \(y_i = \phi + f(x_i,\mathbf{\theta})\), where \(\mathbf{\theta}\) is the vector of coefficients of the above described function represented by \(f(\cdot)\). The default value for \(\phi\) is 0. Note that this restriction must be imposed during the fitting of the model.

Author

Christian Salas-Eljatib.

References

  • Salas-Eljatib C. 2025. Funciones alométricas: reparametrizaciones y características matemáticas. Documento de trabajo No. 1, Serie: Cuadernos de biometría, Laboratorio de Biometría y Modelación Forestal, Universidad de Chile. Santiago, Chile. 51 p. https://biometriaforestal.uchile.cl

Examples

Run this code
# Predictor variable to be used is 40 
# Using the function
inv.fx(x=40,a=25,b=115)
# The effect of the constant term phi
inv.fx(x=40,a=25,b=115, phi=2.5)
 

Run the code above in your browser using DataLab