| kozakln.fx | R Documentation |
Function of the natural log-transformed Kozak (1988) taper equation model, based upon the model parameters, and the tree variables: diameter, total height, and stem height. The mathematical expression is as follows
\ln{d_{l_{i}}}=\alpha_0 + \alpha_1 \ln{d_i}+\alpha_2 {d_i}+
\beta_1 \ln{(X_{l_{i}})} z_{l_{i}}^{2} +
\beta_2 \ln{(X_{l_{i}})} \ln{(z_{l_{i}}+0.001)} +
\beta_3 \ln{(X_{l_{i}})} \sqrt{z_{l_{i}}} +\\
\beta_4 \ln{(X_{l_{i}})} e^{z_{l_{i}}} +
\beta_5 \ln{(X_{l_{i}})} \frac{d_i}{h_i},
where: d_{l_{i}} is the stem diameter at stem-height
h_{l_{i}} for the i-th tree; and
d_i and h_i are the tree-level variables
diameter at breast height and total height, respectively, for
tje i-th tree. The other terms are
z_{l_{i}}=\frac{h_{l_{i}}}{h_i},
X_{l_{i}}=\frac{ 1-\sqrt{ z_{l_{i}}} }{ 1-\sqrt{p} },
with p being the inflextion point.
kozakln.fx(d, h, hl, paramod, p = 0.2, c0 = 0.001)
d |
is the diameter at breast height (1.3 m) of the tree. The measurement unit is cm in the metric system, but ultimately it will depend on how the model was previously fitted, because of the measurement unit of the variables included. |
h |
is total height of the tree. |
hl |
is stem height within the tree,
thus |
paramod |
is a vector having the eight coefficients
of the taper model in the following order:
|
p |
is the inflextion height. By default is set to 0.2 |
c0 |
is a constant build-in the model. By default is set to 0.001. |
Returns the diameter of the stem at the
stem-height h_l, thus d_l, for the natural
log-transformed Kozak (1988) functional form, based upon tree
diameter d and total height h. Therefore, the
result applies the back-transformation by using the anti-log
function, i.e., exp().
Christian Salas-Eljatib.
Kozak A. 1988. A variable-exponent taper equation. Canadian Journal of Forest Research 18: 1363-1368. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1139/x88-213")}
# Parameters
a0<- 0.04338410; a1<- 0.88657485; a2<- 0.00446052;b1<- 1.978196;
b2<- -0.40676847; b3<- 3.50815520; b4<- -1.84177070;b5<- 0.19647175
coefs<-c(a0,a1,a2,b1,b2,b3,b4,b5);p.coef <- 0.25
# Tree attributes
dbh <- 40; toth <- 25
# Using the function
hl.int <- c(0.3, 1.3, 5)
dl.hat <- kozakln.fx(d=dbh,h=toth,hl=hl.int,paramod=coefs,p=p.coef)
cbind(hl.int,dl.hat)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.