| lang.fx | R Documentation |
Function of the Langhmuir model, based upon two parameters, and a single predictor variable, as follows
y_i= \alpha \left(\frac{1}{1+\frac{1}{\beta x_i}}\right),
where: y_i and x_i are the response
and predictor variable, respectively, for the i-th observation;
and the rest are parameters (i.e., coefficients). Further details
of this function can be found in Salas-Eljatib (2025).
lang.fx(x, alpha, beta, upsilon = 0)
x |
is the predictor variable. |
alpha |
is the coefficient-parameter |
beta |
is the coefficient-parameter |
upsilon |
is an optional constant term that force the prediction
of y when x=0. Thus, the new model becomes
|
Returns the response variable based upon the predictor variable and the coefficients.
Christian Salas-Eljatib.
Khayyun TS, Mseer AH. 2019. Comparison of the experimental results with the Langmuir and Freundlich models for copper removal on limestone adsorbent. Applied Water Science 9(8):170.
Salas-Eljatib C. 2025. Funciones alométricas: reparametrizaciones y características matemáticas. Documento de trabajo No. 1, Serie: Cuadernos de biometría, Laboratorio de Biometría y Modelación Forestal, Universidad de Chile. Santiago, Chile. 51 p. https://biometriaforestal.uchile.cl
# Predictor variable values to be used
time<-seq(.1,60,by=0.01)
# Using the function
y<-lang.fx(x=time, alpha=37,beta=0.05)
plot(time,y,type="l")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.