lang.fx: Function to computes the result of the Curtis's allometric
model.
Description
Function of the Langhmuir model, based
upon two parameters, and a single predictor variable, as
follows
$$y_i= \alpha \left(\frac{1}{1+\frac{1}{\beta x_i}}\right),$$
where: \(y_i\) and \(x_i\) are the response
and predictor variable, respectively, for the i-th observation;
and the rest are parameters (i.e., coefficients). Further details
of this function can be found in Salas-Eljatib (2025).
Usage
lang.fx(x, a = alpha, b = beta, phi = 0)
Value
Returns the response variable based upon
the predictor variable and the coefficients.
Arguments
x
is the predictor variable.
a
is the coefficient-parameter \(\alpha\).
b
is the coefficient-parameter \(\beta\).
phi
is an optional constant term that force the prediction
of y when x=0. Thus, the new model becomes
\( y_i = \phi+ f(x_i,\mathbf{\theta})\), where
\(\mathbf{\theta}\) is the vector of coefficients of
the above described function represented by
\(f(\cdot)\). The default
value for \(\phi\) is 0.
Author
Christian Salas-Eljatib.
References
Khayyun TS, Mseer AH. 2019. Comparison of the experimental
results with the Langmuir and Freundlich models for copper removal
on limestone adsorbent. Applied Water Science 9(8):170.
Salas-Eljatib C. 2025. Funciones alométricas: reparametrizaciones
y características matemáticas. Documento de trabajo No. 1,
Serie: Cuadernos de biometría, Laboratorio de Biometría y
Modelación Forestal, Universidad de Chile. Santiago, Chile. 51 p.
https://biometriaforestal.uchile.cl