Learn R Programming

biometrics (version 1.0.3)

logist.fx: A function having the mathematical expression of the Logistic model.

Description

Function of the Logistic model, based upon three parameters and a single predictor variable as follows $$y_i= \frac{\alpha}{1+ \mathrm{e}^{\beta - \gamma x_i}},$$ where: \(y_i\) and \(x_i\) are the response and predictor variable, respectively, for the i-th observation; and the rest are parameters (i.e., coefficients).

Usage

logist.fx(x, a = alpha, b = beta, c = gamma, phi = 0)

Value

Returns the response variable based upon the predictor variable and the coefficients.

Arguments

x

is the predictor variable.

a

is the coefficient-parameter \(\alpha\).

b

is the coefficient-parameter \(\beta\).

c

is the coefficient-parameter \(\gamma\).

phi

is an optional constant term that force the prediction of y when x=0. Thus, the new model becomes \( y_i = \phi+ f\left(x_i,\mathbf{\theta}\right)\), where \(\mathbf{\theta}\) is the vector of coefficients of the above described function represented by \(f(\cdot)\). The default value for \(\phi\) is 0.

Author

Christian Salas-Eljatib.

References

  • Pearl R. 1909. Some recent studies on growth. The American Naturalist 43(509):302-316.

  • Salas-Eljatib C, Mehtatalo L, Gregoire TG, Soto DP, Vargas-Gaete R. 2021. Growth equations in forest research: mathematical basis and model similarities. Current Forestry Reports 7:230-244. tools:::Rd_expr_doi("10.1007/s40725-021-00145-8")

  • Salas-Eljatib C. 2025. Funciones alométricas: reparametrizaciones y características matemáticas. Documento de trabajo No. 1, Serie: Cuadernos de biometría, Laboratorio de Biometría y Modelación Forestal, Universidad de Chile. Santiago, Chile. 51 p. https://biometriaforestal.uchile.cl

Examples

Run this code
# Predictor variable values to be used
time<-seq(5,60,by=0.01)
# Using the function
y<-logist.fx(x=time,a=22,b=1.4,c=.1)
plot(time,y,type="l")
#'  

Run the code above in your browser using DataLab