Learn R Programming

biometrics (version 1.0.3)

meyer.fx: A function having the mathematical expression of the Meyer model.

Description

Function of the Meyer model, based upon two parameters and a single predictor variable as follows $$y_i= \alpha \left(1-\mathrm{e}^{-\beta {x_i}}\right), $$ where: \(y_i\) and \(x_i\) are the response and predictor variable, respectively, for the i-th observation; and the rest are parameters (i.e., coefficients).

Usage

meyer.fx(x, a = alpha, b = beta, phi = 0)

Value

Returns the response variable based upon the predictor variable and the coefficients.

Arguments

x

is the predictor variable.

a

is the coefficient-parameter \(\alpha\).

b

is the coefficient-parameter \(\beta\).

phi

is an optional constant term that force the prediction of y when x=0. Thus, the new model becomes \( y_i = \phi+ f\left(x_i,\mathbf{\theta}\right)\), where \(\mathbf{\theta}\) is the vector of coefficients of the above described function represented by \(f(\cdot)\). The default value for \(\phi\) is 0.

Author

Christian Salas-Eljatib.

References

  • Meyer HA. 1940. A mathematical expression for height curves. Journal of Forestry 38(5):415-420.

  • Salas-Eljatib C. 2025. Funciones alométricas: reparametrizaciones y características matemáticas. Documento de trabajo No. 1, Serie: Cuadernos de biometría, Laboratorio de Biometría y Modelación Forestal, Universidad de Chile. Santiago, Chile. 51 p. https://biometriaforestal.uchile.cl

Examples

Run this code
# Predictor variable values to be used
time<-seq(5,60,by=0.01)
# Using the function
y<-meyer.fx(x=time,a=20,b=.07)
plot(time,y,type="l")
 

Run the code above in your browser using DataLab