| mmenten.fx | R Documentation |
Function of the Michaelis-Menten model, based upon two parameters and a single predictor variable as follows
y_i= \alpha
\left(\frac{x_i}{\beta+x_i} \right),
where: y_i and x_i are the response
and predictor variable, respectively, for the i-th observation;
and the rest are parameters (i.e., coefficients).
mmenten.fx(x, alpha, beta, upsilon = 0)
x |
is the predictor variable. |
alpha |
is the coefficient-parameter |
beta |
is the coefficient-parameter |
upsilon |
is an optional constant term that force the prediction
of y when x=0. Thus, the new model becomes
|
Returns the response variable based upon the predictor variable and the coefficients.
Christian Salas-Eljatib.
Michaelis L, ML Menten. 1913. Die kinetik der invertinwirkung. Biochemische Zeitschrift 49:333–369.
Salas-Eljatib C, P Corvalán, N Pino, PJ Donoso, DP Soto.
Modelos de efectos mixtos de altura-diámetro para Drimys winteri en el sur (41-43 S) de Chile. Bosque 40(1):71-80.
Salas-Eljatib C. 2025. Funciones alométricas: reparametrizaciones y características matemáticas. Documento de trabajo No. 1, Serie: Cuadernos de biometría, Laboratorio de Biometría y Modelación Forestal, Universidad de Chile. Santiago, Chile. 51 p. https://biometriaforestal.uchile.cl
# Predictor variable values to be used
time<-seq(5,60,by=0.01)
# Using the function
y<-mmenten.fx(x=time,alpha=30,beta=13)
plot(time,y,type="l")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.