| mmweibull | R Documentation |
Estimates the parameters of the Weibull probability density
function based on the method of moments. It is based on the
2-parameter reparemetrization of the function, i.e., the
shape and scale parameters.
mmweibull(y)
y |
a vector having the randon variable values. |
Althought the original function was written by Dr Oscar García, and the corresponding reference is provided, the current function has some changes to make it of a broader use.
The main output is a list with the two estimated parameters and the number of observations being used for estimating the parameters.
Dr Oscar García and Christian Salas-Eljatib.
García, O. 1981. Simplified method-of-moments estimation for the Weibull distribution. New Zealand Journal of Forestry Science 11(3): 304-306.
# Random variable to be studied
library(datana)
yvar<-llancahue$dbh
summary(yvar)
hist(yvar)
# Using the function
mmweibull(y=yvar)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.