| ogawa.fx | R Documentation |
Function of the Ogawa allometric model, based upon parameters (i.e., coefficients) and a variable, as defined by the mathematical expression
{y_i}= \left(\frac{1}{\alpha}
+ \frac{1}{\beta {x_i}^{\gamma}}\right)^{-1},
where: y_i and x_i are the response
and predictor variable, respectively, for the i-th observation;
and the rest are parameters (i.e., coefficients).
Further details on this function can be found in
Salas-Eljatib (2025).
ogawa.fx(x, alpha, beta, gamma, upsilon = 0)
x |
is the predictor variable. |
alpha |
is the coefficient-parameter |
beta |
is the coefficient-parameter |
gamma |
is the coefficient-parameter |
upsilon |
is an optional constant term that force the prediction
of y when x=0. Thus, the new model becomes
|
Returns the inverse of the response variable based upon the predictor variable and the coefficients shown above.
Christian Salas-Eljatib.
Kohyama T, T Hara, T Tadaki. 1990. Patterns of trunk diameter, tree height and crown depth in crowded abies stands. Annals of Botany 65(5):567–574.
Salas-Eljatib C. 2026. Funciones alométricas: reparametrizaciones y características matemáticas. Documento de trabajo No. 1, Serie: Cuadernos de biometría, Laboratorio de Biometría y Modelación Forestal, Universidad de Chile. Santiago, Chile. 53 p. https://biometriaforestal.uchile.cl
# Predictor variable values to be used
time<-seq(5,60,by=0.01)
# Using the function
d<-ogawa.fx(x=time,alpha=22,beta=0.013,gamma=1.13)
plot(time,d,type="l")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.