ogawa.fx: Function that computes the result of the Ogawa allometric
model.
Description
Function of the Ogawa allometric
model, based upon parameters (i.e., coefficients) and a variable,
as defined by the mathematical expression
$$\frac{1}{y_i}= \frac{1}{\alpha}
+ \frac{1}{\beta {x_i}^{\gamma}},
$$
where: \(y_i\) and \(x_i\) are the response
and predictor variable, respectively, for the i-th observation;
and the rest are parameters (i.e., coefficients).
Further details on this function can be found in
Salas-Eljatib (2025).
Usage
ogawa.fx(x, alpha, beta, gamma, phi = 0)
Value
Returns the inverse of the response variable based upon
the predictor variable and the coefficients shown above.
Arguments
x
is the predictor variable.
alpha
is the coefficient-parameter \(\alpha\).
beta
is the coefficient-parameter \(\beta\).
gamma
is the coefficient-parameter \(\gamma\).
phi
is an optional constant term that force the prediction
of y when x=0. Thus, the new model becomes
\( y_i = \phi+ f(x_i,\mathbf{\theta})\), where
\(\mathbf{\theta}\) is the vector of coefficients of
the above described function represented by
\(f(\cdot)\). The default
value for \(\phi\) is 0.
Author
Christian Salas-Eljatib.
References
Kohyama T, T Hara, T Tadaki. 1990. Patterns of trunk diameter,
tree height and crown depth in crowded abies stands. Annals of
Botany 65(5):567–574.
Salas-Eljatib C. 2026. Funciones alométricas: reparametrizaciones
y características matemáticas. Documento de trabajo No. 1,
Serie: Cuadernos de biometría, Laboratorio de Biometría y
Modelación Forestal, Universidad de Chile. Santiago, Chile. 53 p.
https://biometriaforestal.uchile.cl
# Predictor variable values to be usedtime<-seq(5,60,by=0.01)
# Using the functiond<-ogawa.fx(x=time,alpha=22,beta=0.013,gamma=1.13)
plot(time,d,type="l")