Learn R Programming

biometrics (version 1.0.3)

pinusSpp: Tree-level variables of several sample plots of invasive Pinus spp in Chile

Description

These are tree-lavel measurement data from Pinus spp invasion in Araucaria-Nothofagus forests in the Malalcahuello National Reserve in La Araucanía region in southhern Chile, measured in 2012. There are 26 plots and plot size is 100 m².

Usage

data(pinusSpp)

Arguments

Format

Contains eight variables, as follows:

plot.id

Plot sample ID.

plot.size

Plot size, en m\(^{2}\).

lat.s

Decimal coordinate of S latitude.

long.w

Decimal coordinate of W longitude.

indv.id

Tree identificator number in each plot. Same indv.id for multi-stem trees.

stem.id

Stem identificator number in each plot.

spp

Species.

dbh

Diameter at breast-height, in cm.

toth

Total height, in m.

hcb

Height to crown base, in m.

crown.lenght

Crown lenght, in m.

References

  • Cobar-Carranza A, Garcia R, Pauchard A, Pena E. 2014. Effect of Pinus contorta invasion on forest fuel properties and its potential implications on the fire regime of Araucaria araucana and Nothofagus antarctica forests. Biological Invasions. 16(11): 2273-2291. tools:::Rd_expr_doi("10.1007/s10530-014-0663-8")

Examples

Run this code
data(pinusSpp)
head(pinusSpp)
length(unique(pinusSpp$plot.id))
boxplot(dbh~plot.id, data=pinusSpp)

Run the code above in your browser using DataLab