Learn R Programming

biometrics (version 1.0.3)

popvol: Population of stand-volume for 400 elements.

Description

The data corresponds to a list of 400 elements of a population of the variable forest volume (in m\(^{3}\)/ha) measured in field plots of 0.1 ha of area. Therefore, the data emerge from a grid of 20 rows by 20 columns, completely covering a forest of 40 ha.

Usage

data(popvol)

Arguments

Format

Contains two variables, as follows:

plot.id

Plot number, or ID.

vol

Stand volume, in m\(^{3}\)/ha

References

  • Zohrer F. 1980. Forstinventur. Ein Leitfaden fur Studium und Praxis. Pareys Studientexte Nr. 26. Parey. Berlin, Germany. 207

  • Loetsch F, Haller KE. 1964. Forest inventory. Volume 1. Bayerischer Landwirtschaftsverlag Gmbh. Munchen, Germany. 436 p.

Examples

Run this code
data(popvol)
sum(popvol$vol)
mean(popvol$vol)
hist(popvol$vol)

Run the code above in your browser using DataLab