| power.fx | R Documentation |
Function of the power model, based upon the model parameters, and a single predictor variable as follows
y_i = \alpha x_i^{\beta}
where: y_i and x_i are the response
and predictor variable, respectively for the i-th observation;
and the rest are parameters (i.e., coefficients).
power.fx(x, alpha, beta, upsilon = 0)
x |
is the predictor variable. |
alpha |
is the coefficient-parameter |
beta |
is the coefficient-parameter |
upsilon |
is an optional constant term that force the prediction
of y when x=0. Thus, the new model becomes
|
Returns the response variable based upon the predictor variable and the coefficients.
Christian Salas-Eljatib.
Salas-Eljatib C. 2025. Funciones alométricas: reparametrizaciones y características matemáticas. Documento de trabajo No. 1, Serie: Cuadernos de biometría, Laboratorio de Biometría y Modelación Forestal, Universidad de Chile. Santiago, Chile. 51 p. https://biometriaforestal.uchile.cl
# Predictor variable to be used is 30
# Using the function
power.fx(x=30,alpha=2.86,beta=.49)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.