Learn R Programming

biometrics (version 1.0.3)

power.fx: Function to computes the result of the power model, as a classical allometric functional form.

Description

Function of the power model, based upon the model parameters, and a single predictor variable as follows $$ y_i = \alpha x_i^{\beta} $$ where: \(y_i\) and \(x_i\) are the response and predictor variable, respectively for the i-th observation; and the rest are parameters (i.e., coefficients).

Usage

power.fx(x, a = alpha, b = beta, phi = 0)

Value

Returns the response variable based upon the predictor variable and the coefficients.

Arguments

x

is the predictor variable.

a

is the coefficient-parameter \(\alpha\).

b

is the coefficient-parameter \(\beta\).

phi

is an optional constant term that force the prediction of y when x=0. Thus, the new model becomes \( y_i = \phi+ f(x_i,\mathbf{\theta})\), where \(\mathbf{\theta}\) is the vector of coefficients of the above described function represented by \(f(\cdot)\). The default value for \(\phi\) is 0.

Author

Christian Salas-Eljatib.

References

  • Salas-Eljatib C. 2025. Funciones alométricas: reparametrizaciones y características matemáticas. Documento de trabajo No. 1, Serie: Cuadernos de biometría, Laboratorio de Biometría y Modelación Forestal, Universidad de Chile. Santiago, Chile. 51 p. https://biometriaforestal.uchile.cl

Examples

Run this code
# Predictor variable to be used is 30 
# Using the function
power.fx(x=30,a=2.86,b=.49)
 

Run the code above in your browser using DataLab