| radiatapl | R Documentation |
Tree-level information collected within sample plots in a forestry 13 years-old plantation of Pinus radiata near Capitán Pastene, Southern Chile. The sample plots size is 150 m², and the total area of the plantation is 45 ha.
data(radiatapl)
The data frame contains four variables as follows:
Plot number identification.
Tree number identification.
Diameter at breast height (1.3 m), in cm.
Total height, in m. Not measured for all trees.
Tree-health clasification, assigned to any of the following levels: good, medium, and bad.
The data are provided courtesy of Mr. Mauricio Lobos-Beneventi (Temuco, Chile), and were collected with the help of his colleague, Christian Salas-Eljatib.
data(radiatapl)
head(radiatapl)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.