Learn R Programming

biometrics (version 1.0.3)

radiatapl: Sampling plots data from a Pinus radiata plantation near Capitán Pastene, La Araucanía region, Chile.

Description

Tree-level information collected within sample plots in a forestry 13 years-old plantation of Pinus radiata near Capitán Pastene, Southern Chile. The sample plots size is 150 m², and the total area of the plantation is 45 ha.

Usage

data(radiatapl)

Arguments

Format

The data frame contains four variables as follows:

plot

Plot number identification.

tree

Tree number identification.

dbh

Diameter at breast height (1.3 m), in cm.

heigth

Total height, in m. Not measured for all trees.

sanity

Tree-health clasification, assigned to any of the following levels: good, medium, and bad.

Examples

Run this code
data(radiatapl)
head(radiatapl)

Run the code above in your browser using DataLab