| ratkow.fx | R Documentation |
Function of the Ratkowsky allometric model, based upon parameters (i.e., coefficients) and a variable, as defined by the mathematical expression
y_i= \alpha
\mathrm{e}^{\left(\frac{-\beta}{x_i +\gamma}\right)},
where: y_i and x_i are the response
and predictor variable, respectively, for the i-th observation;
and the rest are parameters (i.e., coefficients).
Further details on this function can be found in
Salas-Eljatib (2025).
ratkow.fx(x, alpha, beta, gamma, upsilon = 0)
x |
is the predictor variable. |
alpha |
is the coefficient-parameter |
beta |
is the coefficient-parameter |
gamma |
is the coefficient-parameter |
upsilon |
is an optional constant term that force the prediction
of y when x=0. Thus, the new model becomes
|
Returns the response variable based upon the predictor variable and the coefficients.
Christian Salas-Eljatib.
Zhang L. 1997. Cross-validation of non-linear growth functions for modelling tree height-diameter relationships. Annals of Botany 79(3):251–257.
Salas-Eljatib C. 2025. Funciones alométricas: reparametrizaciones y características matemáticas. Documento de trabajo No. 1, Serie: Cuadernos de biometría, Laboratorio de Biometría y Modelación Forestal, Universidad de Chile. Santiago, Chile. 51 p. https://biometriaforestal.uchile.cl
# Predictor variable values to be used
d<-seq(5,60,by=0.01)
# Using the function
h<-ratkow.fx(x=d,alpha=28,beta=34,gamma=.85)
plot(d,h,type="l")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.