Learn R Programming

biometrics (version 1.0.3)

stage.fx: Function that computes the result of the Stage allometric model.

Description

Function of the Stage allometric model, based upon parameters (i.e., coefficients) and a variable, as defined by the mathematical expression $$y_i= \alpha \mathrm{e}^{\left(-\beta ({x_i}^{-\gamma}) \right)}, $$ where: \(y_i\) and \(x_i\) are the response and predictor variable, respectively, for the i-th observation; and the rest are parameters (i.e., coefficients). Further details on this function can be found in Salas-Eljatib (2025).

Usage

stage.fx(x, a = alpha, b = beta, c = gamma, phi = 0)

Value

Returns the response variable based upon the predictor variable and the coefficients.

Arguments

x

is the predictor variable.

a

is the coefficient-parameter \(\alpha\).

b

is the coefficient-parameter \(\beta\).

c

is the coefficient-parameter \(\gamma\).

phi

is an optional constant term that force the prediction of y when x=0. Thus, the new model becomes \( y_i = \phi+ f(x_i,\mathbf{\theta})\), where \(\mathbf{\theta}\) is the vector of coefficients of the above described function represented by \(f(\cdot)\). The default value for \(\phi\) is 0.

Author

Christian Salas-Eljatib.

References

  • Stage AR. 1963. A mathematical approach to polymorphic site index curves for Grand Fir. Forest Sci. 9(2):167-180. tools:::Rd_expr_doi("10.1093/forestscience/9.2.167")

  • Salas-Eljatib C. 2025. Funciones alométricas: reparametrizaciones y características matemáticas. Documento de trabajo No. 1, Serie: Cuadernos de biometría, Laboratorio de Biometría y Modelación Forestal, Universidad de Chile. Santiago, Chile. 51 p. https://biometriaforestal.uchile.cl

Examples

Run this code
# Predictor variable values to be used
time<-seq(5,60,by=0.01)
# Using the function
d<-stage.fx(x=time,a=28,b=56,c=1.19)
plot(time,d,type="l")
 

Run the code above in your browser using DataLab