| standtab | R Documentation |
Creates a stand table, i.e. a table that describes the tree density
of a forest segregated by a tree-size variable y. The most common
example is to use diameter at breast-heigth (i.e., d) as the
variable, thus the resulting table is a way to describe the
diameter distribution.
standtab(
data,
plot.area,
y.for.class,
yclass.amp,
metric = TRUE,
want.basal.area = FALSE,
...
)
data |
data frame having the tree list of a sample plot. |
plot.area |
column name having the plot area in m |
y.for.class |
a text of the column-name having the tree-size variable to be used to segregated the tree density. |
yclass.amp |
a numeric value establishing the width of each
class of the variable |
metric |
is a logic value, the default is to |
want.basal.area |
is a logic value, if set to |
... |
aditional options for basic stats functions. |
For a given imputed tree list of a sample plot, tree density is computed by classes of the tree-size variable. Note that the imputed-tree list must have all the tree-level variables needed to compute stand-level variables, such as, diameter and plot size.
Returns a stand table.
Christian Salas-Eljatib.
Salas-Eljatib C. 2025. Biometría y Modelación Forestal. Borrador de libro, en revisión. 352 p.
## Dataframe to be used
df<-biometrics::eucaplot2
#see the metadata by typing ?eucaplot2
head(df)
datana::descstat(df[,c("dap","atot")])
## Preparing the treelist, in the required format
df$parce<-1;df$sup.plot<-500;amp.diam=2;
out<-standtab(data=df,plot.area="sup.plot",y.for.class = "dap",
yclass.amp = amp.diam)
out
#the following sum
sum(out$nha.class)
# must be equal to the stand-level density (in trees/ha)
df$expf<-10000/df$sup.plot;sum(df$expf)
# Do you want to add the stand basal area segregated by `y.for.class`
out2<-standtab(data=df,plot.area="sup.plot",y.for.class = "dap",
yclass.amp = amp.diam, want.basal.area = TRUE)
out2
#the following sum
sum(out2$gha.class)
# must be equal to the stand-level basal area (in m2/ha)
df$g<-gtree(x=df$dap);df$gtree.ha<-df$g*df$expf;sum(df$gtree.ha)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.