| standtabCoihue | R Documentation |
Stand table for a secondary forest of Nothofagus dombeyi (coihue) en Chile.
data(standtabCoihue)
The data has the following columns
Diameter class, in cm.
Density for the respective diameter class, in trees/ha.
Basal area for the respective diameter class,
in m^{2}/ha.
The forest was located in the Andean foothills in the Araucanía region in southern Chile. Data from Prof. Christian Salas-Eljatib, Universidad de Chile, Santiago, Chile.
Donoso C. 1995. Bosques Templados de Chile y Argentina. Editorial Universitaria. Santiago, Chile.
data(standtabCoihue)
df<-standtabCoihue
df<-df[-nrow(df),]
# Diameter distribution plot
barplot(df$nha, legend = TRUE, beside = TRUE, las=1,
names.arg = as.numeric(df$diam.cl),
ylab="Density (trees/ha)",xlab="Diameter class (cm)")
abline(h=0)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.