Learn R Programming

biometrics (version 1.0.3)

standtabCoihue: Stand table for a Nothofagus dombeyi (coihue) forest

Description

Stand table for a secondary forest of Nothofagus dombeyi (coihue) en Chile.

Usage

data(standtabCoihue)

Arguments

Format

The data has the following columns

diam.cl

Diameter class, in cm.

nha

Density for the respective diameter class, in trees/ha.

gha

Basal area for the respective diameter class, in m\(^{2}\)/ha.

References

  • Donoso C. 1995. Bosques Templados de Chile y Argentina. Editorial Universitaria. Santiago, Chile.

Examples

Run this code
data(standtabCoihue)
df<-standtabCoihue
df<-df[-nrow(df),]
# Diameter distribution plot 
barplot(df$nha, legend = TRUE, beside = TRUE, las=1,
        names.arg = as.numeric(df$diam.cl),
        ylab="Density (trees/ha)",xlab="Diameter class (cm)")
abline(h=0)

Run the code above in your browser using DataLab