| standtabRauli | R Documentation |
Stand tables for secondary Nothofagus alpina-dominated forests in different locations in southern Chile.
data(standtabRauli)
The data has the following columns
Study site.
Location within a study site.
Lower limit of the diameter class, in cm.
Upper limit of the diameter class, in cm.
Diameter class, in cm.
Tree density for the respective diameter class, in trees/ha.
Forest ID code, a combination of columns site
and sector.
Tree density by diameter classes (i.e., stand table). Data were digitized from table No. 4 of Wadsworth (1976).
Wadsworth RK. 1976. Aspectos ecologicos y crecimiento del raulí (Nothofagus alpina) y sus asociados en bosques de segundo crecimiento de las provincias de Bío-Bío, Malleco y Cautín, Chile. Boletin Técnico No. 37, Fac. Cs. Forestales, Universidad de Chile, Santiago, Chile.
data(standtabRauli)
head(standtabRauli)
df<-standtabRauli
table(df$site,df$sector,df$dclass)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.