Learn R Programming

biometrics (version 1.0.3)

standtabRauli: Stand tables for Nothofagus alpina (raulí) forests

Description

Stand tables for secondary Nothofagus alpina-dominated forests in different locations in southern Chile.

Usage

data(standtabRauli)

Arguments

Format

The data has the following columns

site

Study site.

sector

Location within a study site.

low.cd

Lower limit of the diameter class, in cm.

upp.cd

Upper limit of the diameter class, in cm.

dclass

Diameter class, in cm.

nha.dcl

Tree density for the respective diameter class, in trees/ha.

forest.id

Forest ID code, a combination of columns site and sector.

References

  • Wadsworth RK. 1976. Aspectos ecologicos y crecimiento del raulí (Nothofagus alpina) y sus asociados en bosques de segundo crecimiento de las provincias de Bío-Bío, Malleco y Cautín, Chile. Boletin Técnico No. 37, Fac. Cs. Forestales, Universidad de Chile, Santiago, Chile.

Examples

Run this code
data(standtabRauli)
head(standtabRauli)
df<-standtabRauli
table(df$site,df$sector,df$dclass)

Run the code above in your browser using DataLab