| standtabRoble | R Documentation |
Average stand table for secondary forests of Nothofagus obliqua (roble) forests, between 40 and 50 years-old, in the Malleco, Cautín, and Valdiva provinces in southern Chile.
data(standtabRoble)
The data has the following columns
Diameter class, in cm.
Density for the respective diameter class, in trees/ha.
The stand table is from Puente et al. (1979), as a part of a study regarding secondary Nothofagus forests in southern Chile.
Puente M, C Donoso, R Peñaloza, E Morales. 1979. Estudio de raleo y otras técnicas para el manejo de renovales de raulí (Nothofagus alpina) y roble (Nothofagus obliqua). Etapa I: Identificación y caracterización de renovales de raulí y roble. Informe de convenio No. 5, Proyecto CONAF/PNUD/FAO-CHI/76/003, Santiago, Chile. 88 p.
data(standtabRoble)
df<-standtabRoble
df<-df[-nrow(df),]
# Diameter distribution plot
barplot(df$nha, legend = TRUE, beside = TRUE, las=1,
names.arg = df$diam.cl,
ylab="Density (trees/ha)",xlab="Diameter class (cm)")
abline(h=0)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.