Learn R Programming

biometrics (version 1.0.3)

strandg.fx: A function having the mathematical expression of the Strand model.

Description

Function of the Strand generalized model, based upon three parameters and a single predictor variable as follows $$y_i= \left(\frac{x_i}{\alpha +\beta x_i}\right)^{\gamma},$$ where: \(y_i\) and \(x_i\) are the response and predictor variable, respectively, for the i-th observation; and the rest are parameters (i.e., coefficients).

Usage

strandg.fx(x, a = alpha, b = beta, c = gamma, phi = 0)

Value

Returns the response variable based upon the predictor variable and the coefficients.

Arguments

x

is the predictor variable.

a

is the coefficient-parameter \(\alpha\).

b

is the coefficient-parameter \(\beta\).

c

is the coefficient-parameter \(\gamma\).

phi

is an optional constant term that force the prediction of y when x=0. Thus, the new model becomes \( y_i = \phi+ f(x_i,\mathbf{\theta})\), where \(\mathbf{\theta}\) is the vector of coefficients of the above described function represented by \(f(\cdot)\). The default value for \(\phi\) is 0.

Author

Christian Salas-Eljatib.

References

  • Strand L. 1964. Numerical constructions of site-index curves. Forest Sci. 10(4):410-414.

  • Salas-Eljatib C. 2025. Funciones alométricas: reparametrizaciones y características matemáticas. Documento de trabajo No. 1, Serie: Cuadernos de biometría, Laboratorio de Biometría y Modelación Forestal, Universidad de Chile. Santiago, Chile. 51 p. https://biometriaforestal.uchile.cl

Examples

Run this code
# Predictor variable values to be used
time<-seq(5,60,by=0.01)
# Using the function
y<-strandg.fx(x=time,a=0.98,b=0.52,c=4.83)
plot(time,y,type="l")
 

Run the code above in your browser using DataLab