Learn R Programming

biometrics (version 1.0.3)

treegrowth: Diameter and height growth of Grand-fir sample trees.

Description

Diameter and height growth of 66 Grand-fir trees. Data derived from stem analysis sample trees collected by Dr. Albert Stage (US Forest Service, Moscow, ID, USA.)

Usage

data(treegrowth)

Arguments

Format

Contains seven column, as follows:

tree.no

Tree number identificator. An unique number to each sample tree.

forest

Forest type.

habitat

Forest habitat type.

tree.code

A composite tree code representing the following columns: tree.id-forest-habitat

age

Age, in yr

dbh

Diameter at breast-height, in cm. Originally measured in inches, and was converted to cm using a single decimal.

toth

Total height, in m. Originally measured in feet, and was converted to m using a single decimal.

References

  • Stage, A. R., 1963. A mathematical approach to polymorphic site index curves for Grand fir. Forest Science 9 (2), 167–180.

Examples

Run this code
data(treegrowth)
df<-treegrowth
head(df)
require(lattice)
xyplot(dbh~age, groups = tree.code,data=df, type="b")

Run the code above in your browser using DataLab