| treelistinve | R Documentation |
Tree-level variables measured within three sample plots in a forest sampling effort. This sort of work is commonly referred as a forest inventory. Notice that plots might have different areas. The sampling was carried out in a secondary forest of Nothofagus obliqua in the Rucamanque experimental station, near the city of Temuco, in southern Chile.
data(treelistinve)
Contains tree-level variables, as follows:
Plot number.
Plot size, in m^{2}.
Tree identificator
Species common name as follows: Olivillo=Aextocicon puncatatum, Tepa=Laureliopsis philippiana, Lingue=Persea lingue, Coigue=Nothofagus dombeyi, Roble=Nothofagus obliqua, Other=Other
Diameter at breast-height, in cm.
Total height, in m. Only measured for some sample trees.
The data is provided courtesy of Prof. Christian Salas-Eljatib, Universidad de Chile (Santiago, Chile).
Salas C. 2001. Caracterización básica del relicto de Biodiversidad Rucamanque. Bosque Nativo, 29:3-9. https://eljatib.com/publication/2001-06-01_caracterizacion_basi/
Salas C. 2002. Ajuste y validación de ecuaciones de volumen para un relicto del bosque de Roble-Laurel-Lingue. Bosque 23(2): 81-92. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.4067/S0717-92002002000200009")} https://eljatib.com/publication/2002-07-01_ajuste_y_validacion_/
data(treelistinve)
head(treelistinve)
tapply(treelistinve$dbh,treelistinve$species,summary)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.