Learn R Programming

biometrics (version 1.0.3)

treelistinve: Tree-list data from a forest sampling work

Description

Tree-level variables measured within three sample plots in a forest sampling effort. This sort of work is commonly referred as a forest inventory. Notice that plots might have different areas. The sampling was carried out in a secondary forest of Nothofagus obliqua in the Rucamanque experimental station, near the city of Temuco, in southern Chile.

Usage

data(treelistinve)

Arguments

Format

Contains tree-level variables, as follows:

plot

Plot number.

plot.size

Plot size, in m\(^{2}\).

tree

Tree identificator

species

Species common name as follows: Olivillo=Aextocicon puncatatum, Tepa=Laureliopsis philippiana, Lingue=Persea lingue, Coigue=Nothofagus dombeyi, Roble=Nothofagus obliqua, Other=Other

dbh

Diameter at breast-height, in cm.

toth

Total height, in m. Only measured for some sample trees.

References

Examples

Run this code
data(treelistinve)
head(treelistinve)
tapply(treelistinve$dbh,treelistinve$species,summary)

Run the code above in your browser using DataLab