| weib.fx | R Documentation |
Function of the Weibull allometric model, based upon three parameters and a single predictor variable as follows
y_i= \alpha
\left( 1-\mathrm{e}^{-\beta {x_i}}\right)^{\gamma},
where: y_i and x_i are the response
and predictor variable, respectively, for the i-th observation;
and the rest are parameters (i.e., coefficients).
weib.fx(x, alpha, beta, gamma, upsilon = 0)
x |
is the predictor variable. |
alpha |
is the coefficient-parameter |
beta |
is the coefficient-parameter |
gamma |
is the coefficient-parameter |
upsilon |
is an optional constant term that force the prediction
of y when x=0. Thus, the new model becomes
|
Returns the response variable based upon the predictor variable and the coefficients.
Christian Salas-Eljatib.
Weibull W. 1951. A statistical distribution function of wide applicability. J. Appl. Mech.-Trans. ASME 18(3):293-297.
Yang RC, A Kozak, JH Smith. 1978. The potential of Weibull-type functions as flexible growth curves. Can. J. For. Res. 8(2):424-431.
Salas-Eljatib C. 2025. Funciones alométricas: reparametrizaciones y características matemáticas. Documento de trabajo No. 1, Serie: Cuadernos de biometría, Laboratorio de Biometría y Modelación Forestal, Universidad de Chile. Santiago, Chile. 51 p. https://biometriaforestal.uchile.cl
# Predictor variable values to be used
time<-seq(5,60,by=0.01)
# Using the function
y<-weib.fx(x=time,alpha=23.06,beta=.13,gamma=.63)
plot(time,y,type="l")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.