weib.fx: A function having the mathematical expression of
the Weibull allometric model.
Description
Function of the Weibull allometric model, based
upon three parameters and a single predictor variable as
follows
$$y_i= \alpha
\left( 1-\mathrm{e}^{-\beta {x_i}}\right)^{\gamma},
$$
where: \(y_i\) and \(x_i\) are the response
and predictor variable, respectively, for the i-th observation;
and the rest are parameters (i.e., coefficients).
Usage
weib.fx(x, a = alpha, b = beta, c = gamma, phi = 0)
Value
Returns the response variable based upon
the predictor variable and the coefficients.
Arguments
x
is the predictor variable.
a
is the coefficient-parameter \(\alpha\).
b
is the coefficient-parameter \(\beta\).
c
is the coefficient-parameter \(\gamma\).
phi
is an optional constant term that force the prediction
of y when x=0. Thus, the new model becomes
\( y_i = \phi+ f(x_i,\mathbf{\theta})\), where
\(\mathbf{\theta}\) is the vector of coefficients of
the above described function represented by
\(f(\cdot)\). The default
value for \(\phi\) is 0.
Author
Christian Salas-Eljatib.
References
Weibull W. 1951. A statistical distribution function of
wide applicability. J. Appl. Mech.-Trans. ASME 18(3):293-297.
Yang RC, A Kozak, JH Smith. 1978. The potential of
Weibull-type functions as flexible growth curves.
Can. J. For. Res. 8(2):424-431.
Salas-Eljatib C. 2025. Funciones alométricas: reparametrizaciones
y características matemáticas. Documento de trabajo No. 1,
Serie: Cuadernos de biometría, Laboratorio de Biometría y
Modelación Forestal, Universidad de Chile. Santiago, Chile. 51 p.
https://biometriaforestal.uchile.cl