wykoff.fx: A function having the mathematical expression of
the Wykoff model.
Description
Function of the Wykoff model, based
upon two parameters and a single predictor variable as
follows
$$y_i= \mathrm{e}^{\left(\alpha+\frac{\beta}{x_i+1} \right)},
$$
where: \(y_i\) and \(x_i\) are the response
and predictor variable, respectively, for the i-th
observation; and the rest are parameters (i.e., coefficients).
Usage
wykoff.fx(x, a = alpha, b = beta, phi = 0)
Value
Returns the response variable based upon
the predictor variable and the coefficients.
Arguments
x
is the predictor variable.
a
is the coefficient-parameter \(\alpha\).
b
is the coefficient-parameter \(\beta\).
phi
is an optional constant term that force the prediction
of y when x=0. Thus, the new model becomes
\( y_i = \phi+ f\left(x_i,\mathbf{\theta}\right)\), where
\(\mathbf{\theta}\) is the vector of coefficients of
the above described function represented by
\(f(\cdot)\). The default
value for \(\phi\) is 0.
Author
Christian Salas-Eljatib.
References
Wykoff WR, NL Crookston, AR Stage. 1982. User’s guide to the
Stand Prognosis Model. USDA For. Serv. Gen. Tech. Rep.
INT-133, USA. 112 p.
Salas-Eljatib C. 2025. Funciones alométricas: reparametrizaciones
y características matemáticas. Documento de trabajo No. 1,
Serie: Cuadernos de biometría, Laboratorio de Biometría y
Modelación Forestal, Universidad de Chile. Santiago, Chile. 51 p.
https://biometriaforestal.uchile.cl